# coding: utf-8

"""
    CyberSource Merged Spec

    All CyberSource API specs merged together. These are available at https://developer.cybersource.com/api/reference/api-reference.html

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import sys
import os
import re

# python 2 and python 3 compatibility library
from six import iteritems

from ..configuration import Configuration
from ..api_client import ApiClient


class TokenizationApi(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """
	
    def __init__(self, merchant_config, api_client=None):
        config = Configuration()
        if api_client:
            self.api_client = api_client
        else:
            if not config.api_client:
                config.api_client = ApiClient()
            self.api_client = config.api_client
        self.api_client.set_configuration(merchant_config) 


    def tokenize(self, tokenize_request, **kwargs):
        """
        Tokenize Card
        Returns a token representing the supplied card details. The token replaces card data and can be used as the Subscription ID in the CyberSource Simple Order API or SCMP API. This is an unauthenticated call that you should initiate from your customer’s device or browser.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.tokenize(tokenize_request, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param TokenizeRequest tokenize_request: (required)
        :return: FlexV1TokensPost200Response
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.tokenize_with_http_info(tokenize_request, **kwargs)
        else:
            (data) = self.tokenize_with_http_info(tokenize_request, **kwargs)
            return data

    def tokenize_with_http_info(self, tokenize_request, **kwargs):
        """
        Tokenize Card
        Returns a token representing the supplied card details. The token replaces card data and can be used as the Subscription ID in the CyberSource Simple Order API or SCMP API. This is an unauthenticated call that you should initiate from your customer’s device or browser.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.tokenize_with_http_info(tokenize_request, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param TokenizeRequest tokenize_request: (required)
        :return: FlexV1TokensPost200Response
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['tokenize_request']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method tokenize" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'tokenize_request' is set
        if ('tokenize_request' not in params) or (params['tokenize_request'] is None):
            raise ValueError("Missing the required parameter `tokenize_request` when calling `tokenize`")


        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'tokenize_request' in params:
            body_params = params['tokenize_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json;charset=utf-8'])

        # Authentication setting
        auth_settings = []

        return self.api_client.call_api(f'/flex/v1/tokens', 'POST',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type='FlexV1TokensPost200Response',
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)



# coding: utf-8

"""
    CyberSource Merged Spec

    All CyberSource API specs merged together. These are available at https://developer.cybersource.com/api/reference/api-reference.html

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import os
import sys
import unittest

import CyberSource
from CyberSource.rest import ApiException
from CyberSource.models.tmsv2customers__embedded import Tmsv2customersEmbedded


class TestTmsv2customersEmbedded(unittest.TestCase):
    """ Tmsv2customersEmbedded unit test stubs """

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testTmsv2customersEmbedded(self):
        """
        Test Tmsv2customersEmbedded
        """
        # FIXME: construct object with mandatory attributes with example values
        #model = CyberSource.models.tmsv2customers__embedded.Tmsv2customersEmbedded()
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    CyberSource Merged Spec

    All CyberSource API specs merged together. These are available at https://developer.cybersource.com/api/reference/api-reference.html

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class Riskv1authenticationsBuyerInformation(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'personal_identification': 'list[Ptsv2paymentsBuyerInformationPersonalIdentification]',
        'mobile_phone': 'int'
    }

    attribute_map = {
        'personal_identification': 'personalIdentification',
        'mobile_phone': 'mobilePhone'
    }

    def __init__(self, personal_identification=None, mobile_phone=None):
        """
        Riskv1authenticationsBuyerInformation - a model defined in Swagger
        """

        self._personal_identification = None
        self._mobile_phone = None

        if personal_identification is not None:
          self.personal_identification = personal_identification
        self.mobile_phone = mobile_phone

    @property
    def personal_identification(self):
        """
        Gets the personal_identification of this Riskv1authenticationsBuyerInformation.
        This array contains detailed information about the buyer's form of persoanl identification.

        :return: The personal_identification of this Riskv1authenticationsBuyerInformation.
        :rtype: list[Ptsv2paymentsBuyerInformationPersonalIdentification]
        """
        return self._personal_identification

    @personal_identification.setter
    def personal_identification(self, personal_identification):
        """
        Sets the personal_identification of this Riskv1authenticationsBuyerInformation.
        This array contains detailed information about the buyer's form of persoanl identification.

        :param personal_identification: The personal_identification of this Riskv1authenticationsBuyerInformation.
        :type: list[Ptsv2paymentsBuyerInformationPersonalIdentification]
        """

        self._personal_identification = personal_identification

    @property
    def mobile_phone(self):
        """
        Gets the mobile_phone of this Riskv1authenticationsBuyerInformation.
        Cardholder’s mobile phone number. **Important** Required for Visa Secure transactions in Brazil. Do not use this request field for any other types of transactions. 

        :return: The mobile_phone of this Riskv1authenticationsBuyerInformation.
        :rtype: int
        """
        return self._mobile_phone

    @mobile_phone.setter
    def mobile_phone(self, mobile_phone):
        """
        Sets the mobile_phone of this Riskv1authenticationsBuyerInformation.
        Cardholder’s mobile phone number. **Important** Required for Visa Secure transactions in Brazil. Do not use this request field for any other types of transactions. 

        :param mobile_phone: The mobile_phone of this Riskv1authenticationsBuyerInformation.
        :type: int
        """
        if mobile_phone is None:
            raise ValueError("Invalid value for `mobile_phone`, must not be `None`")

        self._mobile_phone = mobile_phone

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, Riskv1authenticationsBuyerInformation):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    CyberSource Merged Spec

    All CyberSource API specs merged together. These are available at https://developer.cybersource.com/api/reference/api-reference.html

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class InvoicingV2InvoicesPost201ResponseInvoiceInformation(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'invoice_number': 'str',
        'description': 'str',
        'due_date': 'date',
        'allow_partial_payments': 'bool',
        'payment_link': 'str',
        'delivery_mode': 'str'
    }

    attribute_map = {
        'invoice_number': 'invoiceNumber',
        'description': 'description',
        'due_date': 'dueDate',
        'allow_partial_payments': 'allowPartialPayments',
        'payment_link': 'paymentLink',
        'delivery_mode': 'deliveryMode'
    }

    def __init__(self, invoice_number=None, description=None, due_date=None, allow_partial_payments=None, payment_link=None, delivery_mode=None):
        """
        InvoicingV2InvoicesPost201ResponseInvoiceInformation - a model defined in Swagger
        """

        self._invoice_number = None
        self._description = None
        self._due_date = None
        self._allow_partial_payments = None
        self._payment_link = None
        self._delivery_mode = None

        if invoice_number is not None:
          self.invoice_number = invoice_number
        if description is not None:
          self.description = description
        if due_date is not None:
          self.due_date = due_date
        if allow_partial_payments is not None:
          self.allow_partial_payments = allow_partial_payments
        if payment_link is not None:
          self.payment_link = payment_link
        if delivery_mode is not None:
          self.delivery_mode = delivery_mode

    @property
    def invoice_number(self):
        """
        Gets the invoice_number of this InvoicingV2InvoicesPost201ResponseInvoiceInformation.
        Invoice Number.

        :return: The invoice_number of this InvoicingV2InvoicesPost201ResponseInvoiceInformation.
        :rtype: str
        """
        return self._invoice_number

    @invoice_number.setter
    def invoice_number(self, invoice_number):
        """
        Sets the invoice_number of this InvoicingV2InvoicesPost201ResponseInvoiceInformation.
        Invoice Number.

        :param invoice_number: The invoice_number of this InvoicingV2InvoicesPost201ResponseInvoiceInformation.
        :type: str
        """

        self._invoice_number = invoice_number

    @property
    def description(self):
        """
        Gets the description of this InvoicingV2InvoicesPost201ResponseInvoiceInformation.
        The description included in the invoice.

        :return: The description of this InvoicingV2InvoicesPost201ResponseInvoiceInformation.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this InvoicingV2InvoicesPost201ResponseInvoiceInformation.
        The description included in the invoice.

        :param description: The description of this InvoicingV2InvoicesPost201ResponseInvoiceInformation.
        :type: str
        """
        if description is not None and len(description) > 2000:
            raise ValueError("Invalid value for `description`, length must be less than or equal to `2000`")

        self._description = description

    @property
    def due_date(self):
        """
        Gets the due_date of this InvoicingV2InvoicesPost201ResponseInvoiceInformation.
        The invoice due date. This field is required for creating an invoice. Format: `YYYY-MM-DD`, where `YYYY` = year, `MM` = month, and `DD` = day 

        :return: The due_date of this InvoicingV2InvoicesPost201ResponseInvoiceInformation.
        :rtype: date
        """
        return self._due_date

    @due_date.setter
    def due_date(self, due_date):
        """
        Sets the due_date of this InvoicingV2InvoicesPost201ResponseInvoiceInformation.
        The invoice due date. This field is required for creating an invoice. Format: `YYYY-MM-DD`, where `YYYY` = year, `MM` = month, and `DD` = day 

        :param due_date: The due_date of this InvoicingV2InvoicesPost201ResponseInvoiceInformation.
        :type: date
        """

        self._due_date = due_date

    @property
    def allow_partial_payments(self):
        """
        Gets the allow_partial_payments of this InvoicingV2InvoicesPost201ResponseInvoiceInformation.
        If set to `true`, the payer can make a partial invoice payment.

        :return: The allow_partial_payments of this InvoicingV2InvoicesPost201ResponseInvoiceInformation.
        :rtype: bool
        """
        return self._allow_partial_payments

    @allow_partial_payments.setter
    def allow_partial_payments(self, allow_partial_payments):
        """
        Sets the allow_partial_payments of this InvoicingV2InvoicesPost201ResponseInvoiceInformation.
        If set to `true`, the payer can make a partial invoice payment.

        :param allow_partial_payments: The allow_partial_payments of this InvoicingV2InvoicesPost201ResponseInvoiceInformation.
        :type: bool
        """

        self._allow_partial_payments = allow_partial_payments

    @property
    def payment_link(self):
        """
        Gets the payment_link of this InvoicingV2InvoicesPost201ResponseInvoiceInformation.
        Returns the payment link to an invoice when the invoice status is `SENT`, `CREATED`, `PARTIAL`, or `PAID`.

        :return: The payment_link of this InvoicingV2InvoicesPost201ResponseInvoiceInformation.
        :rtype: str
        """
        return self._payment_link

    @payment_link.setter
    def payment_link(self, payment_link):
        """
        Sets the payment_link of this InvoicingV2InvoicesPost201ResponseInvoiceInformation.
        Returns the payment link to an invoice when the invoice status is `SENT`, `CREATED`, `PARTIAL`, or `PAID`.

        :param payment_link: The payment_link of this InvoicingV2InvoicesPost201ResponseInvoiceInformation.
        :type: str
        """

        self._payment_link = payment_link

    @property
    def delivery_mode(self):
        """
        Gets the delivery_mode of this InvoicingV2InvoicesPost201ResponseInvoiceInformation.
        If set to `None`, the invoice is created, and its status is set to 'CREATED', but no email is sent.    Possible values:        - `None`   - `Email`  

        :return: The delivery_mode of this InvoicingV2InvoicesPost201ResponseInvoiceInformation.
        :rtype: str
        """
        return self._delivery_mode

    @delivery_mode.setter
    def delivery_mode(self, delivery_mode):
        """
        Sets the delivery_mode of this InvoicingV2InvoicesPost201ResponseInvoiceInformation.
        If set to `None`, the invoice is created, and its status is set to 'CREATED', but no email is sent.    Possible values:        - `None`   - `Email`  

        :param delivery_mode: The delivery_mode of this InvoicingV2InvoicesPost201ResponseInvoiceInformation.
        :type: str
        """

        self._delivery_mode = delivery_mode

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, InvoicingV2InvoicesPost201ResponseInvoiceInformation):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



from authenticationsdk.http.HTTPSignatureToken import *
from authenticationsdk.jwt.Token import *
from authenticationsdk.core.ExceptionHandling import *
import authenticationsdk.util.ExceptionAuth


# This class calls for the generation of Signature message depending on the authentication type
class Authorization:

    # This method generates and return a encrypted signature based on the Authentication type
    def get_token(self, mconfig, date_time, logger):
        authentication_type = mconfig.authentication_type
        self.validate_request_type_method(mconfig)
        # Initializing the logger object

        try:
            # HTTP-Call

            if authentication_type.upper() == GlobalLabelParameters.HTTP.upper():
                http_sig_token = HTTPSignatureToken()
                http_sig_token.http_signature_token(mconfig, date_time)
                sig_token = http_sig_token.get_token()
                # Logging the parameters Content-Type,Merchant id,Date ,Host to the log file
                if mconfig.enable_log is True:
                    logger.info("Using Request Target:   " + mconfig.request_target)
                    logger.info("Authentication Type:   " + mconfig.authentication_type)
                    logger.info("Request-Type:      " + mconfig.request_type_method)
                    logger.info(GlobalLabelParameters.CONTENT_TYPE + ":   " + GlobalLabelParameters.APPLICATION_JSON)
                    logger.info(GlobalLabelParameters.MERCHANT_ID + ":   " + str(mconfig.merchant_id))
                    logger.info(GlobalLabelParameters.DATE + ":   " + date_time)
                    logger.info(GlobalLabelParameters.HOST + ":   " + mconfig.request_host)
                    # Logging the Digest when Request_type_method is Post
                    if mconfig.request_type_method.upper() == GlobalLabelParameters.POST or mconfig.request_type_method.upper() == GlobalLabelParameters.PUT:
                        digest_obj = DigestAndPayload()
                        encoded_digest = digest_obj.string_digest_generation(
                            mconfig.request_json_path_data)
                        logger.info(
                            GlobalLabelParameters.DIGEST + ":" + GlobalLabelParameters.DIGEST_PREFIX + (
                                encoded_digest).decode("utf-8"))
                    logger.info("Signature:     " + sig_token)

                return sig_token
            # JWT-Call
            elif authentication_type.upper() == GlobalLabelParameters.JWT.upper():

                jwt_sig_token = JwtSignatureToken()
                jwt_sig_token.jwt_signature_token(mconfig, date_time)
                sig_token_jwt = jwt_sig_token.get_token()

                # Logging the parameters Content-Type,Merchant id,Date ,Host to the log file
                if mconfig.enable_log is True:
                    logger.info("Using Request Target:   " + mconfig.request_target)
                    logger.info("Authentication Type:   " + mconfig.authentication_type)
                    logger.info("Request-Type:      " + mconfig.request_type_method)
                    logger.info(GlobalLabelParameters.CONTENT_TYPE + ":   " + GlobalLabelParameters.APPLICATION_JSON)
                    logger.info(GlobalLabelParameters.MERCHANT_ID + ":   " + str(mconfig.merchant_id))
                    logger.info(GlobalLabelParameters.DATE + ":   " + date_time)
                    logger.info(GlobalLabelParameters.HOST + ":   " + mconfig.request_host)
                    # Logging the Digest when Request_type_method is Post
                    logger.info("Authorization Bearer:     " + sig_token_jwt.decode("utf-8"))
                return sig_token_jwt
            else:
                raise ApiException(1, GlobalLabelParameters.AUTH_ERROR)
        except ApiException as e:
            authenticationsdk.util.ExceptionAuth.log_exception(logger, e, mconfig)
        except IOError as e:
            authenticationsdk.util.ExceptionAuth.log_exception(logger,
                                                               GlobalLabelParameters.FILE_NOT_FOUND + str(e.filename),
                                                               mconfig)
        except OSError as e:
            authenticationsdk.util.ExceptionAuth.log_exception(logger,
                                                               GlobalLabelParameters.SYSTEM_ERROR + str(e.filename),
                                                               mconfig)
        except Exception as e:
            if "mac verify failure" in str(e):
                authenticationsdk.util.ExceptionAuth.log_exception(logger, GlobalLabelParameters.INCORRECT_KEY_PASSWORD,
                                                                   mconfig)
            else:
                authenticationsdk.util.ExceptionAuth.log_exception(logger, repr(e), mconfig)

    # noinspection PyMethodMayBeStatic
    def validate_request_type_method(self, mconfig):

        if not (
                mconfig.request_type_method.upper() == GlobalLabelParameters.GET or mconfig.request_type_method.upper() == GlobalLabelParameters.POST or mconfig.request_type_method.upper() == GlobalLabelParameters.PUT or mconfig.request_type_method.upper() == GlobalLabelParameters.DELETE or mconfig.request_type_method.upper() == GlobalLabelParameters.PATCH):
            raise ApiException(1, GlobalLabelParameters.INVALID_REQUEST_TYPE_METHOD)



# coding: utf-8

"""
    CyberSource Merged Spec

    All CyberSource API specs merged together. These are available at https://developer.cybersource.com/api/reference/api-reference.html

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import os
import sys
import unittest

import CyberSource
from CyberSource.rest import ApiException
from CyberSource.apis.invoices_api import InvoicesApi


class TestInvoicesApi(unittest.TestCase):
    """ InvoicesApi unit test stubs """

    def setUp(self):
        self.api = CyberSource.apis.invoices_api.InvoicesApi()

    def tearDown(self):
        pass

    def test_create_invoice(self):
        """
        Test case for create_invoice

        Create a New Invoice
        """
        pass

    def test_get_all_invoices(self):
        """
        Test case for get_all_invoices

        Get a List of Invoices
        """
        pass

    def test_get_invoice(self):
        """
        Test case for get_invoice

        Get Invoice Details
        """
        pass

    def test_perform_cancel_action(self):
        """
        Test case for perform_cancel_action

        Cancel an Invoice
        """
        pass

    def test_perform_send_action(self):
        """
        Test case for perform_send_action

        Send an Invoice
        """
        pass

    def test_update_invoice(self):
        """
        Test case for update_invoice

        Update an Invoice
        """
        pass


if __name__ == '__main__':
    unittest.main()



from authenticationsdk.http.GetSignatureParameter import *

from authenticationsdk.core.TokenGeneration import *
from authenticationsdk.util.GlobalLabelParameters import *


# HttpSigToken return SignatureHeader Value that contains following paramters
# keyid     -- Merchant ID obtained from EBC portal
# algorithm -- Should have value as "HmacSHA256"
# headers   -- List of all header name passed in the Signature paramter below
# String getHeaders = "host date (request-target)" + " " + "v-c-merchant-id"
# String postHeaders = "host date (request-target) digest v-c-merchant-id"
# Note: Digest is not passed for GET calls
# signature -- Signature header has paramter called signature
# Paramter 'Signature' must contain all the paramters mentioned in header above in given order


class HTTPSignatureToken(TokenGeneration):
    def __init__(self):
        self.merchant_config_sighead = None
        self.merchant_key_id_sig = None
        self.merchant_secret_key_sig = None
        self.http_method_sig = None
        self.http_merchant_id = None
        self.http_get_id = None
        self.date_time = None

    def http_signature_token(self, mconfig,date_time):

        self.merchant_config_sighead = mconfig
        self.merchant_key_id_sig = str(mconfig.merchant_keyid)
        self.merchant_secret_key_sig = str(mconfig.merchant_secretkey)
        self.http_method_sig = mconfig.request_type_method
        self.http_merchant_id = mconfig.merchant_id
        self.date_time = date_time
		

    def get_token(self):

        return self.signature_header()

    def signature_header(self):

        # Initializing the logger object

        header_list = ([])
        # Key id is the key obtained from EBC
        header_list.append(
            GlobalLabelParameters.KEY_ID + str(self.merchant_config_sighead.merchant_keyid) + "\"")
        header_list.append(GlobalLabelParameters.ALGORITHM)
        # Headers are chosen based on HTTP method.Digest is not required for get method

        if self.http_method_sig.upper() == GlobalLabelParameters.GET:
            getheaders = "host date (request-target)" + " " + "v-c-merchant-id"
            header_list.append(GlobalLabelParameters.HEADERS_PARAM + getheaders + "\"")
        elif self.http_method_sig.upper() == GlobalLabelParameters.POST:
            postheaders = "host date (request-target) digest v-c-merchant-id"
            header_list.append(GlobalLabelParameters.HEADERS_PARAM + postheaders + "\"")
        elif self.http_method_sig.upper() == GlobalLabelParameters.PUT:
            putheaders = "host date (request-target) digest v-c-merchant-id"
            header_list.append(GlobalLabelParameters.HEADERS_PARAM + putheaders + "\"")
        elif self.http_method_sig.upper() == GlobalLabelParameters.PATCH:
            patchheaders = "host date (request-target) digest v-c-merchant-id"
            header_list.append(GlobalLabelParameters.HEADERS_PARAM + patchheaders + "\"")
        elif self.http_method_sig.upper() == GlobalLabelParameters.DELETE:
            deleteheaders = "host date (request-target)" + " " + "v-c-merchant-id"
            header_list.append(GlobalLabelParameters.HEADERS_PARAM + deleteheaders + "\"")

        get_signature_paramobj = GetSignatureParameter()
        # Getting value of the signature parameter
        signature = get_signature_paramobj.get_signature_parameter(self.merchant_config_sighead,
                                                                   self.merchant_secret_key_sig,
                                                                   self.http_merchant_id, self.http_method_sig,
                                                             self.date_time)

        header_list.append(
            GlobalLabelParameters.SIGNATURE_HEADER + signature + "\"")
        signature_value = ''.join(header_list)
		


        return signature_value



import json
import os
from authenticationsdk.core.ExceptionHandling import *
from authenticationsdk.util.GlobalLabelParameters import *



class PropertiesUtil:
    def __init__(self):
        self.cybs_path = "..\Resources/cybs.json"


    # This method reads from cybs.json if provided else it reads from configuration file
    def properties_util(self):
        if os.path.exists(self.cybs_path):

            with open(self.cybs_path) as json_data:
                details_dict = json.load(json_data)

                return details_dict

        else:
            raise ApiException(1, GlobalLabelParameters.INVALID_CYBS_PATH)






# coding: utf-8

"""
    CyberSource Merged Spec

    All CyberSource API specs merged together. These are available at https://developer.cybersource.com/api/reference/api-reference.html

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class InvoicingV2InvoicesAllGet200ResponseInvoices(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'links': 'InvoicingV2InvoicesAllGet200ResponseLinks1',
        'id': 'str',
        'status': 'str',
        'customer_information': 'InvoicingV2InvoicesAllGet200ResponseCustomerInformation',
        'invoice_information': 'InvoicingV2InvoicesAllGet200ResponseInvoiceInformation',
        'order_information': 'InvoicingV2InvoicesAllGet200ResponseOrderInformation'
    }

    attribute_map = {
        'links': '_links',
        'id': 'id',
        'status': 'status',
        'customer_information': 'customerInformation',
        'invoice_information': 'invoiceInformation',
        'order_information': 'orderInformation'
    }

    def __init__(self, links=None, id=None, status=None, customer_information=None, invoice_information=None, order_information=None):
        """
        InvoicingV2InvoicesAllGet200ResponseInvoices - a model defined in Swagger
        """

        self._links = None
        self._id = None
        self._status = None
        self._customer_information = None
        self._invoice_information = None
        self._order_information = None

        if links is not None:
          self.links = links
        if id is not None:
          self.id = id
        if status is not None:
          self.status = status
        if customer_information is not None:
          self.customer_information = customer_information
        if invoice_information is not None:
          self.invoice_information = invoice_information
        if order_information is not None:
          self.order_information = order_information

    @property
    def links(self):
        """
        Gets the links of this InvoicingV2InvoicesAllGet200ResponseInvoices.

        :return: The links of this InvoicingV2InvoicesAllGet200ResponseInvoices.
        :rtype: InvoicingV2InvoicesAllGet200ResponseLinks1
        """
        return self._links

    @links.setter
    def links(self, links):
        """
        Sets the links of this InvoicingV2InvoicesAllGet200ResponseInvoices.

        :param links: The links of this InvoicingV2InvoicesAllGet200ResponseInvoices.
        :type: InvoicingV2InvoicesAllGet200ResponseLinks1
        """

        self._links = links

    @property
    def id(self):
        """
        Gets the id of this InvoicingV2InvoicesAllGet200ResponseInvoices.
        An unique identification number to identify the submitted request. It is also appended to the endpoint of the resource.  On incremental authorizations, this value with be the same as the identification number returned in the original authorization response.  #### PIN debit Returned for all PIN debit services. 

        :return: The id of this InvoicingV2InvoicesAllGet200ResponseInvoices.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this InvoicingV2InvoicesAllGet200ResponseInvoices.
        An unique identification number to identify the submitted request. It is also appended to the endpoint of the resource.  On incremental authorizations, this value with be the same as the identification number returned in the original authorization response.  #### PIN debit Returned for all PIN debit services. 

        :param id: The id of this InvoicingV2InvoicesAllGet200ResponseInvoices.
        :type: str
        """
        if id is not None and len(id) > 26:
            raise ValueError("Invalid value for `id`, length must be less than or equal to `26`")

        self._id = id

    @property
    def status(self):
        """
        Gets the status of this InvoicingV2InvoicesAllGet200ResponseInvoices.
        The status of the invoice.  Possible values: - DRAFT - CREATED - SENT - PARTIAL - PAID - CANCELED 

        :return: The status of this InvoicingV2InvoicesAllGet200ResponseInvoices.
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """
        Sets the status of this InvoicingV2InvoicesAllGet200ResponseInvoices.
        The status of the invoice.  Possible values: - DRAFT - CREATED - SENT - PARTIAL - PAID - CANCELED 

        :param status: The status of this InvoicingV2InvoicesAllGet200ResponseInvoices.
        :type: str
        """

        self._status = status

    @property
    def customer_information(self):
        """
        Gets the customer_information of this InvoicingV2InvoicesAllGet200ResponseInvoices.

        :return: The customer_information of this InvoicingV2InvoicesAllGet200ResponseInvoices.
        :rtype: InvoicingV2InvoicesAllGet200ResponseCustomerInformation
        """
        return self._customer_information

    @customer_information.setter
    def customer_information(self, customer_information):
        """
        Sets the customer_information of this InvoicingV2InvoicesAllGet200ResponseInvoices.

        :param customer_information: The customer_information of this InvoicingV2InvoicesAllGet200ResponseInvoices.
        :type: InvoicingV2InvoicesAllGet200ResponseCustomerInformation
        """

        self._customer_information = customer_information

    @property
    def invoice_information(self):
        """
        Gets the invoice_information of this InvoicingV2InvoicesAllGet200ResponseInvoices.

        :return: The invoice_information of this InvoicingV2InvoicesAllGet200ResponseInvoices.
        :rtype: InvoicingV2InvoicesAllGet200ResponseInvoiceInformation
        """
        return self._invoice_information

    @invoice_information.setter
    def invoice_information(self, invoice_information):
        """
        Sets the invoice_information of this InvoicingV2InvoicesAllGet200ResponseInvoices.

        :param invoice_information: The invoice_information of this InvoicingV2InvoicesAllGet200ResponseInvoices.
        :type: InvoicingV2InvoicesAllGet200ResponseInvoiceInformation
        """

        self._invoice_information = invoice_information

    @property
    def order_information(self):
        """
        Gets the order_information of this InvoicingV2InvoicesAllGet200ResponseInvoices.

        :return: The order_information of this InvoicingV2InvoicesAllGet200ResponseInvoices.
        :rtype: InvoicingV2InvoicesAllGet200ResponseOrderInformation
        """
        return self._order_information

    @order_information.setter
    def order_information(self, order_information):
        """
        Sets the order_information of this InvoicingV2InvoicesAllGet200ResponseInvoices.

        :param order_information: The order_information of this InvoicingV2InvoicesAllGet200ResponseInvoices.
        :type: InvoicingV2InvoicesAllGet200ResponseOrderInformation
        """

        self._order_information = order_information

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, InvoicingV2InvoicesAllGet200ResponseInvoices):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



import os
class MockData:
    HTTP_VALUES = {
        "authentication_type": "HTTP_SIGNATURE",
        "merchantid": "testrest",
        "run_environment": "CyberSource.Environment.SANDBOX",
        "key_alias": "testrest",
        "key_password": "testrest",
        "key_file_name": "testrest",
        "keys_directory": os.path.join(os.getcwd(),"resources"),
        "merchant_keyid": "08c94330-f618-42a3-b09d-e1e43be5efda",
        "merchant_secretkey": "yBJxy6LjM2TmcPGu+GaJrHtkke25fPpUX+UY6/L/1tE=",
        "enable_log": False,
        "log_file_name": "cybs",
        "log_maximum_size": 10485760,
        "log_directory": os.path.join(os.getcwd(),"Logs"),
        "proxy_address": "userproxy.com",
        "proxy_port": ""
    }
    JWT_VALUES = {
        "authentication_type": "jwt",
        "merchantid": "testrest",
        "run_environment": "CyberSource.Environment.SANDBOX",
        "key_alias": "testrest",
        "key_password": "testrest",
        "key_file_name": "testrest",
        "keys_directory": os.path.join(os.getcwd(),"resources"),
        "merchant_keyid": "08c94330-f618-42a3-b09d-e1e43be5efda",
        "merchant_secretkey": "yBJxy6LjM2TmcPGu+GaJrHtkke25fPpUX+UY6/L/1tE=",
        "enable_log": False,
        "log_file_name": "cybs",
        "log_maximum_size": 10485760,
        "log_directory": os.path.join(os.getcwd(),"Logs"),
        "proxy_address": "userproxy.com",
        "proxy_port": ""
    }
    HTTP_DEFAULT_VALUES = {
        "authentication_type": "HTTP_SIGNATURE",
        "merchantid": "testrest",
        "run_environment": "CyberSource.Environment.SANDBOX",
        "key_alias": "testrest",
        "key_password": "testrest",
        "key_file_name": "testrest",
        "keys_directory": os.path.join(os.getcwd(),"resources"),
        "merchant_keyid": "08c94330-f618-42a3-b09d-e1e43be5efda",
        "merchant_secretkey": "yBJxy6LjM2TmcPGu+GaJrHtkke25fPpUX+UY6/L/1tE=",
        "enable_log": "",
        "log_file_name": "cybs",
        "log_maximum_size": "",
        "log_directory": "",
        "proxy_address": "userproxy.com",
        "proxy_port": ""
    }
    JWT_VALUES_FOR_PRODUCTION = {
        "authentication_type": "jwt",
        "merchantid": "testrest",
        "run_environment": "CyberSource.Environment.PRODUCTION",
        "key_alias": "testrest",
        "key_password": "",
        "key_file_name": "",
        "keys_directory": "",
        "merchant_keyid": "08c94330-f618-42a3-b09d-e1e43be5efda",
        "merchant_secretkey": "yBJxy6LjM2TmcPGu+GaJrHtkke25fPpUX+UY6/L/1tE=",
        "enable_log": False,
        "log_file_name": "cybs",
        "log_maximum_size": 10485760,
        "log_directory": os.path.join(os.getcwd(),"Logs"),
        "proxy_address": "userproxy.com",
        "proxy_port": ""
    }
    REQUEST_DATA = {
        "clientReferenceInformation": {
            "code": "TC50171_3"
        },
        "processingInformation": {
            "commerceIndicator": "internet"
        },
        "aggregatorInformation": {
            "subMerchant": {
                "cardAcceptorID": "1234567890",
                "country": "US",
                "phoneNumber": "650-432-0000",
                "address1": "900 Metro Center",
                "postalCode": "94404-2775",
                "locality": "Foster City",
                "name": "Visa Inc",
                "administrativeArea": "CA",
                "region": "PEN",
                "email": "test@cybs.com"
            },
            "name": "V-Internatio",
            "aggregatorID": "123456789"
        },
        "orderInformation": {
            "billTo": {
                "country": "US",
                "lastName": "VDP",
                "address2": "Address 2",
                "address1": "201 S. Division St.",
                "postalCode": "48104-2201",
                "locality": "Ann Arbor",
                "administrativeArea": "MI",
                "firstName": "RTS",
                "phoneNumber": "999999999",
                "district": "MI",
                "buildingNumber": "123",
                "company": "Visa",
                "email": "test@cybs.com"
            },
            "amountDetails": {
                "totalAmount": "102.21",
                "currency": "USD"
            }
        },
        "paymentInformation": {
            "card": {
                "expirationYear": "2031",
                "number": "5555555555554444",
                "securityCode": "123",
                "expirationMonth": "12",
                "type": "002"
            }
        }
    }
    TRR_DATA = {
        "startDay": "23",
        "timeZone": "America/Chicago",
        "reportDefinitionName": "TransactionRequestClass",
        "startTime": "1100",
        "reportFrequency": "DAILY",
        "ReportName": "TRRReport",
        "reportFormat": "csv",
        "orgId": "testrest",
        "reportType": "detail",
        "reportFields": ["Request.RequestID", "Request.TransactionDate", "Request.MerchantReferenceNumber",
                         "Request.MerchantID"]
    }



import logging
from datetime import datetime
import os


def setup_logger(mconfig):
    # Creating a log directory if the directory is not present
    # If the directory is present then just append in the file
    if mconfig.enable_log is True:
        logger_folder = mconfig.log_directory
        logger_file = os.path.join(logger_folder , mconfig.log_file_name)+ ".log"
        if not os.path.exists(logger_folder):
            os.makedirs(logger_folder)
        if not os.path.exists(logger_file):
            open(logger_file, "a+")
        if logger_file:
            if os.stat(logger_file).st_size > int(mconfig.maximum_size):
                updated_file = os.path.join(logger_folder , mconfig.log_file_name)+"_" + datetime.now().strftime("%Y%m%d%H%M%S") + ".log"
                os.rename(logger_file, updated_file)
        # setting the logger object
        logger = logging.getLogger()
        if not logger.handlers:
            # add a File handler
            handler = logging.FileHandler(filename=logger_file)
            # create a logging format
            formatter = logging.Formatter('%(asctime)s- %(message)s')
            handler.setFormatter(formatter)

            logger.setLevel(logging.INFO)
            # add the handlers to the logger
            logger.addHandler(handler)

        return logger



# coding: utf-8

"""
    CyberSource Merged Spec

    All CyberSource API specs merged together. These are available at https://developer.cybersource.com/api/reference/api-reference.html

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import os
import sys
import unittest

import CyberSource
from CyberSource.rest import ApiException
from CyberSource.apis.report_subscriptions_api import ReportSubscriptionsApi


class TestReportSubscriptionsApi(unittest.TestCase):
    """ ReportSubscriptionsApi unit test stubs """

    def setUp(self):
        self.api = CyberSource.apis.report_subscriptions_api.ReportSubscriptionsApi()

    def tearDown(self):
        pass

    def test_create_standard_or_classic_subscription(self):
        """
        Test case for create_standard_or_classic_subscription

        Create a Standard or Classic Subscription
        """
        pass

    def test_create_subscription(self):
        """
        Test case for create_subscription

        Create Report Subscription for a Report Name by Organization
        """
        pass

    def test_delete_subscription(self):
        """
        Test case for delete_subscription

        Delete Subscription of a Report Name by Organization
        """
        pass

    def test_get_all_subscriptions(self):
        """
        Test case for get_all_subscriptions

        Get All Subscriptions
        """
        pass

    def test_get_subscription(self):
        """
        Test case for get_subscription

        Get Subscription for Report Name
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    CyberSource Merged Spec

    All CyberSource API specs merged together. These are available at https://developer.cybersource.com/api/reference/api-reference.html

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class RiskV1AuthenticationResultsPost201ResponseConsumerAuthenticationInformation(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'acs_rendering_type': 'str',
        'acs_transaction_id': 'str',
        'authentication_result': 'str',
        'authentication_status_msg': 'str',
        'authorization_payload': 'str',
        'cavv': 'str',
        'cavv_algorithm': 'str',
        'directory_server_error_code': 'str',
        'directory_server_error_description': 'str',
        'indicator': 'str',
        'interaction_counter': 'str',
        'eci': 'str',
        'eci_raw': 'str',
        'pares_status': 'str',
        'sdk_transaction_id': 'str',
        'specification_version': 'str',
        'three_ds_server_transaction_id': 'str',
        'ucaf_authentication_data': 'str',
        'ucaf_collection_indicator': 'str',
        'white_list_status': 'str',
        'white_list_status_source': 'str',
        'xid': 'str',
        'directory_server_transaction_id': 'str'
    }

    attribute_map = {
        'acs_rendering_type': 'acsRenderingType',
        'acs_transaction_id': 'acsTransactionId',
        'authentication_result': 'authenticationResult',
        'authentication_status_msg': 'authenticationStatusMsg',
        'authorization_payload': 'authorizationPayload',
        'cavv': 'cavv',
        'cavv_algorithm': 'cavvAlgorithm',
        'directory_server_error_code': 'directoryServerErrorCode',
        'directory_server_error_description': 'directoryServerErrorDescription',
        'indicator': 'indicator',
        'interaction_counter': 'interactionCounter',
        'eci': 'eci',
        'eci_raw': 'eciRaw',
        'pares_status': 'paresStatus',
        'sdk_transaction_id': 'sdkTransactionId',
        'specification_version': 'specificationVersion',
        'three_ds_server_transaction_id': 'threeDSServerTransactionId',
        'ucaf_authentication_data': 'ucafAuthenticationData',
        'ucaf_collection_indicator': 'ucafCollectionIndicator',
        'white_list_status': 'whiteListStatus',
        'white_list_status_source': 'whiteListStatusSource',
        'xid': 'xid',
        'directory_server_transaction_id': 'directoryServerTransactionId'
    }

    def __init__(self, acs_rendering_type=None, acs_transaction_id=None, authentication_result=None, authentication_status_msg=None, authorization_payload=None, cavv=None, cavv_algorithm=None, directory_server_error_code=None, directory_server_error_description=None, indicator=None, interaction_counter=None, eci=None, eci_raw=None, pares_status=None, sdk_transaction_id=None, specification_version=None, three_ds_server_transaction_id=None, ucaf_authentication_data=None, ucaf_collection_indicator=None, white_list_status=None, white_list_status_source=None, xid=None, directory_server_transaction_id=None):
        """
        RiskV1AuthenticationResultsPost201ResponseConsumerAuthenticationInformation - a model defined in Swagger
        """

        self._acs_rendering_type = None
        self._acs_transaction_id = None
        self._authentication_result = None
        self._authentication_status_msg = None
        self._authorization_payload = None
        self._cavv = None
        self._cavv_algorithm = None
        self._directory_server_error_code = None
        self._directory_server_error_description = None
        self._indicator = None
        self._interaction_counter = None
        self._eci = None
        self._eci_raw = None
        self._pares_status = None
        self._sdk_transaction_id = None
        self._specification_version = None
        self._three_ds_server_transaction_id = None
        self._ucaf_authentication_data = None
        self._ucaf_collection_indicator = None
        self._white_list_status = None
        self._white_list_status_source = None
        self._xid = None
        self._directory_server_transaction_id = None

        if acs_rendering_type is not None:
          self.acs_rendering_type = acs_rendering_type
        if acs_transaction_id is not None:
          self.acs_transaction_id = acs_transaction_id
        if authentication_result is not None:
          self.authentication_result = authentication_result
        if authentication_status_msg is not None:
          self.authentication_status_msg = authentication_status_msg
        if authorization_payload is not None:
          self.authorization_payload = authorization_payload
        if cavv is not None:
          self.cavv = cavv
        if cavv_algorithm is not None:
          self.cavv_algorithm = cavv_algorithm
        if directory_server_error_code is not None:
          self.directory_server_error_code = directory_server_error_code
        if directory_server_error_description is not None:
          self.directory_server_error_description = directory_server_error_description
        if indicator is not None:
          self.indicator = indicator
        if interaction_counter is not None:
          self.interaction_counter = interaction_counter
        if eci is not None:
          self.eci = eci
        if eci_raw is not None:
          self.eci_raw = eci_raw
        if pares_status is not None:
          self.pares_status = pares_status
        if sdk_transaction_id is not None:
          self.sdk_transaction_id = sdk_transaction_id
        if specification_version is not None:
          self.specification_version = specification_version
        if three_ds_server_transaction_id is not None:
          self.three_ds_server_transaction_id = three_ds_server_transaction_id
        if ucaf_authentication_data is not None:
          self.ucaf_authentication_data = ucaf_authentication_data
        if ucaf_collection_indicator is not None:
          self.ucaf_collection_indicator = ucaf_collection_indicator
        if white_list_status is not None:
          self.white_list_status = white_list_status
        if white_list_status_source is not None:
          self.white_list_status_source = white_list_status_source
        if xid is not None:
          self.xid = xid
        if directory_server_transaction_id is not None:
          self.directory_server_transaction_id = directory_server_transaction_id

    @property
    def acs_rendering_type(self):
        """
        Gets the acs_rendering_type of this RiskV1AuthenticationResultsPost201ResponseConsumerAuthenticationInformation.
        Identifies the UI Type the ACS will use to complete the challenge. **NOTE**: Only available for App transactions using the Cardinal Mobile SDK. 

        :return: The acs_rendering_type of this RiskV1AuthenticationResultsPost201ResponseConsumerAuthenticationInformation.
        :rtype: str
        """
        return self._acs_rendering_type

    @acs_rendering_type.setter
    def acs_rendering_type(self, acs_rendering_type):
        """
        Sets the acs_rendering_type of this RiskV1AuthenticationResultsPost201ResponseConsumerAuthenticationInformation.
        Identifies the UI Type the ACS will use to complete the challenge. **NOTE**: Only available for App transactions using the Cardinal Mobile SDK. 

        :param acs_rendering_type: The acs_rendering_type of this RiskV1AuthenticationResultsPost201ResponseConsumerAuthenticationInformation.
        :type: str
        """

        self._acs_rendering_type = acs_rendering_type

    @property
    def acs_transaction_id(self):
        """
        Gets the acs_transaction_id of this RiskV1AuthenticationResultsPost201ResponseConsumerAuthenticationInformation.
        Unique transaction identifier assigned by the ACS to identify a single transaction. 

        :return: The acs_transaction_id of this RiskV1AuthenticationResultsPost201ResponseConsumerAuthenticationInformation.
        :rtype: str
        """
        return self._acs_transaction_id

    @acs_transaction_id.setter
    def acs_transaction_id(self, acs_transaction_id):
        """
        Sets the acs_transaction_id of this RiskV1AuthenticationResultsPost201ResponseConsumerAuthenticationInformation.
        Unique transaction identifier assigned by the ACS to identify a single transaction. 

        :param acs_transaction_id: The acs_transaction_id of this RiskV1AuthenticationResultsPost201ResponseConsumerAuthenticationInformation.
        :type: str
        """
        if acs_transaction_id is not None and len(acs_transaction_id) > 36:
            raise ValueError("Invalid value for `acs_transaction_id`, length must be less than or equal to `36`")

        self._acs_transaction_id = acs_transaction_id

    @property
    def authentication_result(self):
        """
        Gets the authentication_result of this RiskV1AuthenticationResultsPost201ResponseConsumerAuthenticationInformation.
        Raw authentication data that comes from the cardissuing bank. Primary authentication field that indicates if authentication was successful and if liability shift occurred. You should examine first the result of this field. This field contains one of these values: - `-1`: Invalid PARes. - `0`: Successful validation. - `1`: Cardholder is not participating, but the attempt to authenticate was recorded. - `6`: Issuer unable to perform authentication. - `9`: Cardholder did not complete authentication. 

        :return: The authentication_result of this RiskV1AuthenticationResultsPost201ResponseConsumerAuthenticationInformation.
        :rtype: str
        """
        return self._authentication_result

    @authentication_result.setter
    def authentication_result(self, authentication_result):
        """
        Sets the authentication_result of this RiskV1AuthenticationResultsPost201ResponseConsumerAuthenticationInformation.
        Raw authentication data that comes from the cardissuing bank. Primary authentication field that indicates if authentication was successful and if liability shift occurred. You should examine first the result of this field. This field contains one of these values: - `-1`: Invalid PARes. - `0`: Successful validation. - `1`: Cardholder is not participating, but the attempt to authenticate was recorded. - `6`: Issuer unable to perform authentication. - `9`: Cardholder did not complete authentication. 

        :param authentication_result: The authentication_result of this RiskV1AuthenticationResultsPost201ResponseConsumerAuthenticationInformation.
        :type: str
        """

        self._authentication_result = authentication_result

    @property
    def authentication_status_msg(self):
        """
        Gets the authentication_status_msg of this RiskV1AuthenticationResultsPost201ResponseConsumerAuthenticationInformation.
        Message that explains the authenticationResult reply field. 

        :return: The authentication_status_msg of this RiskV1AuthenticationResultsPost201ResponseConsumerAuthenticationInformation.
        :rtype: str
        """
        return self._authentication_status_msg

    @authentication_status_msg.setter
    def authentication_status_msg(self, authentication_status_msg):
        """
        Sets the authentication_status_msg of this RiskV1AuthenticationResultsPost201ResponseConsumerAuthenticationInformation.
        Message that explains the authenticationResult reply field. 

        :param authentication_status_msg: The authentication_status_msg of this RiskV1AuthenticationResultsPost201ResponseConsumerAuthenticationInformation.
        :type: str
        """

        self._authentication_status_msg = authentication_status_msg

    @property
    def authorization_payload(self):
        """
        Gets the authorization_payload of this RiskV1AuthenticationResultsPost201ResponseConsumerAuthenticationInformation.
        The Base64 encoded JSON Payload of CB specific Authorization Values returned in the challenge Flow 

        :return: The authorization_payload of this RiskV1AuthenticationResultsPost201ResponseConsumerAuthenticationInformation.
        :rtype: str
        """
        return self._authorization_payload

    @authorization_payload.setter
    def authorization_payload(self, authorization_payload):
        """
        Sets the authorization_payload of this RiskV1AuthenticationResultsPost201ResponseConsumerAuthenticationInformation.
        The Base64 encoded JSON Payload of CB specific Authorization Values returned in the challenge Flow 

        :param authorization_payload: The authorization_payload of this RiskV1AuthenticationResultsPost201ResponseConsumerAuthenticationInformation.
        :type: str
        """

        self._authorization_payload = authorization_payload

    @property
    def cavv(self):
        """
        Gets the cavv of this RiskV1AuthenticationResultsPost201ResponseConsumerAuthenticationInformation.
        Unique identifier generated by the card-issuing bank for Visa, American Express, JCB, Diners Club, and Discover transactions after the customer is authenticated. The value is in base64. When you request the card authorization service, CyberSource automatically converts the value, not the field name, to the format required by your payment processor. 

        :return: The cavv of this RiskV1AuthenticationResultsPost201ResponseConsumerAuthenticationInformation.
        :rtype: str
        """
        return self._cavv

    @cavv.setter
    def cavv(self, cavv):
        """
        Sets the cavv of this RiskV1AuthenticationResultsPost201ResponseConsumerAuthenticationInformation.
        Unique identifier generated by the card-issuing bank for Visa, American Express, JCB, Diners Club, and Discover transactions after the customer is authenticated. The value is in base64. When you request the card authorization service, CyberSource automatically converts the value, not the field name, to the format required by your payment processor. 

        :param cavv: The cavv of this RiskV1AuthenticationResultsPost201ResponseConsumerAuthenticationInformation.
        :type: str
        """
        if cavv is not None and len(cavv) > 255:
            raise ValueError("Invalid value for `cavv`, length must be less than or equal to `255`")

        self._cavv = cavv

    @property
    def cavv_algorithm(self):
        """
        Gets the cavv_algorithm of this RiskV1AuthenticationResultsPost201ResponseConsumerAuthenticationInformation.
        Field that is returned only when the CAVV is generated, which occurs when paresStatus contains the values Y (successful authentication) or A (attempted authentication). If you use the ATOS processor, send the value of this field in the `cavv_algorithm` request field of the authorization service. This field contains one of these values: - `2`: Visa, American Express, JCB, Diners Club, and Discover - `3`: Mastercard 

        :return: The cavv_algorithm of this RiskV1AuthenticationResultsPost201ResponseConsumerAuthenticationInformation.
        :rtype: str
        """
        return self._cavv_algorithm

    @cavv_algorithm.setter
    def cavv_algorithm(self, cavv_algorithm):
        """
        Sets the cavv_algorithm of this RiskV1AuthenticationResultsPost201ResponseConsumerAuthenticationInformation.
        Field that is returned only when the CAVV is generated, which occurs when paresStatus contains the values Y (successful authentication) or A (attempted authentication). If you use the ATOS processor, send the value of this field in the `cavv_algorithm` request field of the authorization service. This field contains one of these values: - `2`: Visa, American Express, JCB, Diners Club, and Discover - `3`: Mastercard 

        :param cavv_algorithm: The cavv_algorithm of this RiskV1AuthenticationResultsPost201ResponseConsumerAuthenticationInformation.
        :type: str
        """
        if cavv_algorithm is not None and len(cavv_algorithm) > 1:
            raise ValueError("Invalid value for `cavv_algorithm`, length must be less than or equal to `1`")

        self._cavv_algorithm = cavv_algorithm

    @property
    def directory_server_error_code(self):
        """
        Gets the directory_server_error_code of this RiskV1AuthenticationResultsPost201ResponseConsumerAuthenticationInformation.
        The directory server error code indicating a problem with this transaction. Note - Max Length of this field is typically 3 characters. 

        :return: The directory_server_error_code of this RiskV1AuthenticationResultsPost201ResponseConsumerAuthenticationInformation.
        :rtype: str
        """
        return self._directory_server_error_code

    @directory_server_error_code.setter
    def directory_server_error_code(self, directory_server_error_code):
        """
        Sets the directory_server_error_code of this RiskV1AuthenticationResultsPost201ResponseConsumerAuthenticationInformation.
        The directory server error code indicating a problem with this transaction. Note - Max Length of this field is typically 3 characters. 

        :param directory_server_error_code: The directory_server_error_code of this RiskV1AuthenticationResultsPost201ResponseConsumerAuthenticationInformation.
        :type: str
        """

        self._directory_server_error_code = directory_server_error_code

    @property
    def directory_server_error_description(self):
        """
        Gets the directory_server_error_description of this RiskV1AuthenticationResultsPost201ResponseConsumerAuthenticationInformation.
        Directory server text and additional detail about the error for this transaction. 

        :return: The directory_server_error_description of this RiskV1AuthenticationResultsPost201ResponseConsumerAuthenticationInformation.
        :rtype: str
        """
        return self._directory_server_error_description

    @directory_server_error_description.setter
    def directory_server_error_description(self, directory_server_error_description):
        """
        Sets the directory_server_error_description of this RiskV1AuthenticationResultsPost201ResponseConsumerAuthenticationInformation.
        Directory server text and additional detail about the error for this transaction. 

        :param directory_server_error_description: The directory_server_error_description of this RiskV1AuthenticationResultsPost201ResponseConsumerAuthenticationInformation.
        :type: str
        """
        if directory_server_error_description is not None and len(directory_server_error_description) > 4096:
            raise ValueError("Invalid value for `directory_server_error_description`, length must be less than or equal to `4096`")

        self._directory_server_error_description = directory_server_error_description

    @property
    def indicator(self):
        """
        Gets the indicator of this RiskV1AuthenticationResultsPost201ResponseConsumerAuthenticationInformation.
        Indicator used to differentiate Internet transactions from other types. The authentication failed if this field is not returned. For Visa, if your payment processor is Streamline, Barclays, AIBMS, or FDC Germany, you receive the value vbv_failure instead of internet when eci is 07. The value of this field is passed automatically to the authorization service if you request the services together. This field contains one of these values: - `aesk`: American Express SafeKey authentication verified successfully. - `aesk_attempted`: Card not enrolled in American Express SafeKey, but the attempt to authenticate was recorded. - `dipb`: Discover ProtectBuy authentication verified successfully. - `dipb_attempted`: Card not enrolled in Discover ProtectBuy, but the attempt to authenticate was recorded. - `internet`: Authentication was not verified successfully. - `js`: J/Secure authentication verified successfully. - `js_attempted`: Card not enrolled in J/Secure, but the attempt to authenticate was recorded. - `moto`: Mail or telephone order. - `pb_attempted`: Card not enrolled in Diners Club ProtectBuy, but the attempt to authenticate was recorded. - `recurring`: Recurring transaction. - `spa`: Mastercard Identity Check authentication verified successfully. - `spa_failure`: Mastercard Identity Check failed authentication. - `vbv`: Visa Secure authentication verified successfully. - `vbv_attempted`: Card not enrolled in Visa Secure, but the attempt to authenticate was recorded. - `vbv_failure`: Visa Secure authentication unavailable. 

        :return: The indicator of this RiskV1AuthenticationResultsPost201ResponseConsumerAuthenticationInformation.
        :rtype: str
        """
        return self._indicator

    @indicator.setter
    def indicator(self, indicator):
        """
        Sets the indicator of this RiskV1AuthenticationResultsPost201ResponseConsumerAuthenticationInformation.
        Indicator used to differentiate Internet transactions from other types. The authentication failed if this field is not returned. For Visa, if your payment processor is Streamline, Barclays, AIBMS, or FDC Germany, you receive the value vbv_failure instead of internet when eci is 07. The value of this field is passed automatically to the authorization service if you request the services together. This field contains one of these values: - `aesk`: American Express SafeKey authentication verified successfully. - `aesk_attempted`: Card not enrolled in American Express SafeKey, but the attempt to authenticate was recorded. - `dipb`: Discover ProtectBuy authentication verified successfully. - `dipb_attempted`: Card not enrolled in Discover ProtectBuy, but the attempt to authenticate was recorded. - `internet`: Authentication was not verified successfully. - `js`: J/Secure authentication verified successfully. - `js_attempted`: Card not enrolled in J/Secure, but the attempt to authenticate was recorded. - `moto`: Mail or telephone order. - `pb_attempted`: Card not enrolled in Diners Club ProtectBuy, but the attempt to authenticate was recorded. - `recurring`: Recurring transaction. - `spa`: Mastercard Identity Check authentication verified successfully. - `spa_failure`: Mastercard Identity Check failed authentication. - `vbv`: Visa Secure authentication verified successfully. - `vbv_attempted`: Card not enrolled in Visa Secure, but the attempt to authenticate was recorded. - `vbv_failure`: Visa Secure authentication unavailable. 

        :param indicator: The indicator of this RiskV1AuthenticationResultsPost201ResponseConsumerAuthenticationInformation.
        :type: str
        """

        self._indicator = indicator

    @property
    def interaction_counter(self):
        """
        Gets the interaction_counter of this RiskV1AuthenticationResultsPost201ResponseConsumerAuthenticationInformation.
        Indicates the number of authentication cycles attempted by the cardholder and is tracked by the Issuing Banks ACS.Example: if customer gets the challenge window and enter in their one time password and hit submit then that interaction counter should just be 1. When customer gets the challenge window and the bank asks if they want to have the one time password  sent to their phone or their email and they have to choose before going to the next screen to enter in their one time password then this interaction count would be 2. One for the selection of how they want the one time password delivered and another with them actually entering in the one time password and hitting the submit button. 

        :return: The interaction_counter of this RiskV1AuthenticationResultsPost201ResponseConsumerAuthenticationInformation.
        :rtype: str
        """
        return self._interaction_counter

    @interaction_counter.setter
    def interaction_counter(self, interaction_counter):
        """
        Sets the interaction_counter of this RiskV1AuthenticationResultsPost201ResponseConsumerAuthenticationInformation.
        Indicates the number of authentication cycles attempted by the cardholder and is tracked by the Issuing Banks ACS.Example: if customer gets the challenge window and enter in their one time password and hit submit then that interaction counter should just be 1. When customer gets the challenge window and the bank asks if they want to have the one time password  sent to their phone or their email and they have to choose before going to the next screen to enter in their one time password then this interaction count would be 2. One for the selection of how they want the one time password delivered and another with them actually entering in the one time password and hitting the submit button. 

        :param interaction_counter: The interaction_counter of this RiskV1AuthenticationResultsPost201ResponseConsumerAuthenticationInformation.
        :type: str
        """
        if interaction_counter is not None and len(interaction_counter) > 2:
            raise ValueError("Invalid value for `interaction_counter`, length must be less than or equal to `2`")

        self._interaction_counter = interaction_counter

    @property
    def eci(self):
        """
        Gets the eci of this RiskV1AuthenticationResultsPost201ResponseConsumerAuthenticationInformation.
        Note This field applies only to non-U.S-issued cards.  For enroll, Numeric electronic commerce indicator (ECI) returned only for Visa, American Express, JCB, Diners Club, and Discover transactions when the card is not enrolled. For more information, see \"Interpreting the Reply,\" page 22.  If you are not using the CyberSource payment services, you must send this value to your payment processor in the subsequent request for card authorization. This field contains one of these values: - `06`: The card can be enrolled. Liability shift. - `07`: The card cannot be enrolled. No liability shift.  For validate, Numeric electronic commerce indicator (ECI) returned only for Visa, American Express, JCB, Diners Club, and Discover transactions. The field is absent when authentication fails. You must send this value to your payment processor in the subsequent request for card authorization. This field contains one of these values: - `05`: Successful authentication - `06`: Authentication attempted - `07`: Failed authentication (No response from the merchant because of a problem.) 

        :return: The eci of this RiskV1AuthenticationResultsPost201ResponseConsumerAuthenticationInformation.
        :rtype: str
        """
        return self._eci

    @eci.setter
    def eci(self, eci):
        """
        Sets the eci of this RiskV1AuthenticationResultsPost201ResponseConsumerAuthenticationInformation.
        Note This field applies only to non-U.S-issued cards.  For enroll, Numeric electronic commerce indicator (ECI) returned only for Visa, American Express, JCB, Diners Club, and Discover transactions when the card is not enrolled. For more information, see \"Interpreting the Reply,\" page 22.  If you are not using the CyberSource payment services, you must send this value to your payment processor in the subsequent request for card authorization. This field contains one of these values: - `06`: The card can be enrolled. Liability shift. - `07`: The card cannot be enrolled. No liability shift.  For validate, Numeric electronic commerce indicator (ECI) returned only for Visa, American Express, JCB, Diners Club, and Discover transactions. The field is absent when authentication fails. You must send this value to your payment processor in the subsequent request for card authorization. This field contains one of these values: - `05`: Successful authentication - `06`: Authentication attempted - `07`: Failed authentication (No response from the merchant because of a problem.) 

        :param eci: The eci of this RiskV1AuthenticationResultsPost201ResponseConsumerAuthenticationInformation.
        :type: str
        """

        self._eci = eci

    @property
    def eci_raw(self):
        """
        Gets the eci_raw of this RiskV1AuthenticationResultsPost201ResponseConsumerAuthenticationInformation.
        ECI value that can be returned for Visa, Mastercard, American Express, JCB, Diners Club, and Discover. The field is absent when authentication fails. If your payment processor is Streamline, you must pass the value of this field instead of the value of `eci` or `ucafCollectionIndicator`.  This field can contain one of these values: - `01`: Authentication attempted (Mastercard) - `02`: Successful authentication (Mastercard) - `05`: Successful authentication (Visa, American Express, JCB, Diners Club, and Discover) - `06`: Authentication attempted (Visa, American Express, JCB, Diners Club, and Discover) 

        :return: The eci_raw of this RiskV1AuthenticationResultsPost201ResponseConsumerAuthenticationInformation.
        :rtype: str
        """
        return self._eci_raw

    @eci_raw.setter
    def eci_raw(self, eci_raw):
        """
        Sets the eci_raw of this RiskV1AuthenticationResultsPost201ResponseConsumerAuthenticationInformation.
        ECI value that can be returned for Visa, Mastercard, American Express, JCB, Diners Club, and Discover. The field is absent when authentication fails. If your payment processor is Streamline, you must pass the value of this field instead of the value of `eci` or `ucafCollectionIndicator`.  This field can contain one of these values: - `01`: Authentication attempted (Mastercard) - `02`: Successful authentication (Mastercard) - `05`: Successful authentication (Visa, American Express, JCB, Diners Club, and Discover) - `06`: Authentication attempted (Visa, American Express, JCB, Diners Club, and Discover) 

        :param eci_raw: The eci_raw of this RiskV1AuthenticationResultsPost201ResponseConsumerAuthenticationInformation.
        :type: str
        """

        self._eci_raw = eci_raw

    @property
    def pares_status(self):
        """
        Gets the pares_status of this RiskV1AuthenticationResultsPost201ResponseConsumerAuthenticationInformation.
        Raw result of the authentication check. If you are configured for Asia, Middle East, and Africa Gateway Processing, you need to send the value of this field in your authorization request. This field can contain one of these values: - `A`: Proof of authentication attempt was generated. - `N`: Customer failed or canceled authentication. Transaction denied. - `U`: Authentication not completed regardless of the reason. - `Y`: Customer was successfully authenticated. 

        :return: The pares_status of this RiskV1AuthenticationResultsPost201ResponseConsumerAuthenticationInformation.
        :rtype: str
        """
        return self._pares_status

    @pares_status.setter
    def pares_status(self, pares_status):
        """
        Sets the pares_status of this RiskV1AuthenticationResultsPost201ResponseConsumerAuthenticationInformation.
        Raw result of the authentication check. If you are configured for Asia, Middle East, and Africa Gateway Processing, you need to send the value of this field in your authorization request. This field can contain one of these values: - `A`: Proof of authentication attempt was generated. - `N`: Customer failed or canceled authentication. Transaction denied. - `U`: Authentication not completed regardless of the reason. - `Y`: Customer was successfully authenticated. 

        :param pares_status: The pares_status of this RiskV1AuthenticationResultsPost201ResponseConsumerAuthenticationInformation.
        :type: str
        """

        self._pares_status = pares_status

    @property
    def sdk_transaction_id(self):
        """
        Gets the sdk_transaction_id of this RiskV1AuthenticationResultsPost201ResponseConsumerAuthenticationInformation.
        SDK unique transaction identifier that is generated on each new transaction. 

        :return: The sdk_transaction_id of this RiskV1AuthenticationResultsPost201ResponseConsumerAuthenticationInformation.
        :rtype: str
        """
        return self._sdk_transaction_id

    @sdk_transaction_id.setter
    def sdk_transaction_id(self, sdk_transaction_id):
        """
        Sets the sdk_transaction_id of this RiskV1AuthenticationResultsPost201ResponseConsumerAuthenticationInformation.
        SDK unique transaction identifier that is generated on each new transaction. 

        :param sdk_transaction_id: The sdk_transaction_id of this RiskV1AuthenticationResultsPost201ResponseConsumerAuthenticationInformation.
        :type: str
        """
        if sdk_transaction_id is not None and len(sdk_transaction_id) > 36:
            raise ValueError("Invalid value for `sdk_transaction_id`, length must be less than or equal to `36`")

        self._sdk_transaction_id = sdk_transaction_id

    @property
    def specification_version(self):
        """
        Gets the specification_version of this RiskV1AuthenticationResultsPost201ResponseConsumerAuthenticationInformation.
        This field contains the 3D Secure version that was used to process the transaction. For example, 1.0.2 or 2.0.0. 

        :return: The specification_version of this RiskV1AuthenticationResultsPost201ResponseConsumerAuthenticationInformation.
        :rtype: str
        """
        return self._specification_version

    @specification_version.setter
    def specification_version(self, specification_version):
        """
        Sets the specification_version of this RiskV1AuthenticationResultsPost201ResponseConsumerAuthenticationInformation.
        This field contains the 3D Secure version that was used to process the transaction. For example, 1.0.2 or 2.0.0. 

        :param specification_version: The specification_version of this RiskV1AuthenticationResultsPost201ResponseConsumerAuthenticationInformation.
        :type: str
        """

        self._specification_version = specification_version

    @property
    def three_ds_server_transaction_id(self):
        """
        Gets the three_ds_server_transaction_id of this RiskV1AuthenticationResultsPost201ResponseConsumerAuthenticationInformation.
        Unique transaction identifier assigned by the 3DS Server to identify a single transaction. 

        :return: The three_ds_server_transaction_id of this RiskV1AuthenticationResultsPost201ResponseConsumerAuthenticationInformation.
        :rtype: str
        """
        return self._three_ds_server_transaction_id

    @three_ds_server_transaction_id.setter
    def three_ds_server_transaction_id(self, three_ds_server_transaction_id):
        """
        Sets the three_ds_server_transaction_id of this RiskV1AuthenticationResultsPost201ResponseConsumerAuthenticationInformation.
        Unique transaction identifier assigned by the 3DS Server to identify a single transaction. 

        :param three_ds_server_transaction_id: The three_ds_server_transaction_id of this RiskV1AuthenticationResultsPost201ResponseConsumerAuthenticationInformation.
        :type: str
        """
        if three_ds_server_transaction_id is not None and len(three_ds_server_transaction_id) > 36:
            raise ValueError("Invalid value for `three_ds_server_transaction_id`, length must be less than or equal to `36`")

        self._three_ds_server_transaction_id = three_ds_server_transaction_id

    @property
    def ucaf_authentication_data(self):
        """
        Gets the ucaf_authentication_data of this RiskV1AuthenticationResultsPost201ResponseConsumerAuthenticationInformation.
        AAV is a unique identifier generated by the card-issuing bank for Mastercard Identity Check transactions after the customer is authenticated. The value is in base64. Include the data in the card authorization request. 

        :return: The ucaf_authentication_data of this RiskV1AuthenticationResultsPost201ResponseConsumerAuthenticationInformation.
        :rtype: str
        """
        return self._ucaf_authentication_data

    @ucaf_authentication_data.setter
    def ucaf_authentication_data(self, ucaf_authentication_data):
        """
        Sets the ucaf_authentication_data of this RiskV1AuthenticationResultsPost201ResponseConsumerAuthenticationInformation.
        AAV is a unique identifier generated by the card-issuing bank for Mastercard Identity Check transactions after the customer is authenticated. The value is in base64. Include the data in the card authorization request. 

        :param ucaf_authentication_data: The ucaf_authentication_data of this RiskV1AuthenticationResultsPost201ResponseConsumerAuthenticationInformation.
        :type: str
        """

        self._ucaf_authentication_data = ucaf_authentication_data

    @property
    def ucaf_collection_indicator(self):
        """
        Gets the ucaf_collection_indicator of this RiskV1AuthenticationResultsPost201ResponseConsumerAuthenticationInformation.
        For enroll, Returned only for Mastercard transactions. Indicates that authentication is not required because the customer is not enrolled. Add the value of this field to the authorization field ucaf_collection_indicator. This field can contain these values: 0, 1.  For validate, Numeric electronic commerce indicator (ECI) returned only for Mastercard Identity Check transactions. The field is absent when authentication fails. You must send this value to your payment processor in the request for card authorization. This field contain one of these values: - `0`: Authentication data not collected, and customer authentication was not completed. - `1`: Authentication data not collected because customer authentication was not completed. - `2`: Authentication data collected because customer completed authentication. 

        :return: The ucaf_collection_indicator of this RiskV1AuthenticationResultsPost201ResponseConsumerAuthenticationInformation.
        :rtype: str
        """
        return self._ucaf_collection_indicator

    @ucaf_collection_indicator.setter
    def ucaf_collection_indicator(self, ucaf_collection_indicator):
        """
        Sets the ucaf_collection_indicator of this RiskV1AuthenticationResultsPost201ResponseConsumerAuthenticationInformation.
        For enroll, Returned only for Mastercard transactions. Indicates that authentication is not required because the customer is not enrolled. Add the value of this field to the authorization field ucaf_collection_indicator. This field can contain these values: 0, 1.  For validate, Numeric electronic commerce indicator (ECI) returned only for Mastercard Identity Check transactions. The field is absent when authentication fails. You must send this value to your payment processor in the request for card authorization. This field contain one of these values: - `0`: Authentication data not collected, and customer authentication was not completed. - `1`: Authentication data not collected because customer authentication was not completed. - `2`: Authentication data collected because customer completed authentication. 

        :param ucaf_collection_indicator: The ucaf_collection_indicator of this RiskV1AuthenticationResultsPost201ResponseConsumerAuthenticationInformation.
        :type: str
        """

        self._ucaf_collection_indicator = ucaf_collection_indicator

    @property
    def white_list_status(self):
        """
        Gets the white_list_status of this RiskV1AuthenticationResultsPost201ResponseConsumerAuthenticationInformation.
        Enables the communication of trusted beneficiary/whitelist status between the ACS, the DS and the 3DS Requestor.  Possible Values:  Y - 3DS Requestor is whitelisted by cardholder  N - 3DS Requestor is not whitelisted by cardholder 

        :return: The white_list_status of this RiskV1AuthenticationResultsPost201ResponseConsumerAuthenticationInformation.
        :rtype: str
        """
        return self._white_list_status

    @white_list_status.setter
    def white_list_status(self, white_list_status):
        """
        Sets the white_list_status of this RiskV1AuthenticationResultsPost201ResponseConsumerAuthenticationInformation.
        Enables the communication of trusted beneficiary/whitelist status between the ACS, the DS and the 3DS Requestor.  Possible Values:  Y - 3DS Requestor is whitelisted by cardholder  N - 3DS Requestor is not whitelisted by cardholder 

        :param white_list_status: The white_list_status of this RiskV1AuthenticationResultsPost201ResponseConsumerAuthenticationInformation.
        :type: str
        """
        if white_list_status is not None and len(white_list_status) > 1:
            raise ValueError("Invalid value for `white_list_status`, length must be less than or equal to `1`")

        self._white_list_status = white_list_status

    @property
    def white_list_status_source(self):
        """
        Gets the white_list_status_source of this RiskV1AuthenticationResultsPost201ResponseConsumerAuthenticationInformation.
        This data element will be populated by the system setting Whitelist Status. Possible Values: 01 - 3DS/ Server/ 02 – DS/03 - ACS 

        :return: The white_list_status_source of this RiskV1AuthenticationResultsPost201ResponseConsumerAuthenticationInformation.
        :rtype: str
        """
        return self._white_list_status_source

    @white_list_status_source.setter
    def white_list_status_source(self, white_list_status_source):
        """
        Sets the white_list_status_source of this RiskV1AuthenticationResultsPost201ResponseConsumerAuthenticationInformation.
        This data element will be populated by the system setting Whitelist Status. Possible Values: 01 - 3DS/ Server/ 02 – DS/03 - ACS 

        :param white_list_status_source: The white_list_status_source of this RiskV1AuthenticationResultsPost201ResponseConsumerAuthenticationInformation.
        :type: str
        """
        if white_list_status_source is not None and len(white_list_status_source) > 2:
            raise ValueError("Invalid value for `white_list_status_source`, length must be less than or equal to `2`")

        self._white_list_status_source = white_list_status_source

    @property
    def xid(self):
        """
        Gets the xid of this RiskV1AuthenticationResultsPost201ResponseConsumerAuthenticationInformation.
        Transaction identifier generated by CyberSource for successful enrollment or validation checks. Use this value, which is in base64, to match an outgoing PAReq with an incoming PARes. CyberSource forwards the XID with the card authorization service to these payment processors in these cases: - Barclays - Streamline (when the **ecommerceIndicator**`=spa`) 

        :return: The xid of this RiskV1AuthenticationResultsPost201ResponseConsumerAuthenticationInformation.
        :rtype: str
        """
        return self._xid

    @xid.setter
    def xid(self, xid):
        """
        Sets the xid of this RiskV1AuthenticationResultsPost201ResponseConsumerAuthenticationInformation.
        Transaction identifier generated by CyberSource for successful enrollment or validation checks. Use this value, which is in base64, to match an outgoing PAReq with an incoming PARes. CyberSource forwards the XID with the card authorization service to these payment processors in these cases: - Barclays - Streamline (when the **ecommerceIndicator**`=spa`) 

        :param xid: The xid of this RiskV1AuthenticationResultsPost201ResponseConsumerAuthenticationInformation.
        :type: str
        """

        self._xid = xid

    @property
    def directory_server_transaction_id(self):
        """
        Gets the directory_server_transaction_id of this RiskV1AuthenticationResultsPost201ResponseConsumerAuthenticationInformation.
        The Directory Server Transaction ID is generated by the Mastercard Directory Server during the authentication transaction and passed back to the merchant with the authentication results. For Cybersource Through Visanet Gateway: The value for this field corresponds to the following data in the TC 33 capture file3: Record: CP01 TCR7, Position: 114-149, Field: MC AVV Verification—Directory Server Transaction ID 

        :return: The directory_server_transaction_id of this RiskV1AuthenticationResultsPost201ResponseConsumerAuthenticationInformation.
        :rtype: str
        """
        return self._directory_server_transaction_id

    @directory_server_transaction_id.setter
    def directory_server_transaction_id(self, directory_server_transaction_id):
        """
        Sets the directory_server_transaction_id of this RiskV1AuthenticationResultsPost201ResponseConsumerAuthenticationInformation.
        The Directory Server Transaction ID is generated by the Mastercard Directory Server during the authentication transaction and passed back to the merchant with the authentication results. For Cybersource Through Visanet Gateway: The value for this field corresponds to the following data in the TC 33 capture file3: Record: CP01 TCR7, Position: 114-149, Field: MC AVV Verification—Directory Server Transaction ID 

        :param directory_server_transaction_id: The directory_server_transaction_id of this RiskV1AuthenticationResultsPost201ResponseConsumerAuthenticationInformation.
        :type: str
        """
        if directory_server_transaction_id is not None and len(directory_server_transaction_id) > 36:
            raise ValueError("Invalid value for `directory_server_transaction_id`, length must be less than or equal to `36`")

        self._directory_server_transaction_id = directory_server_transaction_id

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, RiskV1AuthenticationResultsPost201ResponseConsumerAuthenticationInformation):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    CyberSource Merged Spec

    All CyberSource API specs merged together. These are available at https://developer.cybersource.com/api/reference/api-reference.html

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import os
import sys
import unittest

import CyberSource
from CyberSource.rest import ApiException
from CyberSource.models.pts_v2_payments_post201_response_risk_information_ip_address import PtsV2PaymentsPost201ResponseRiskInformationIpAddress


class TestPtsV2PaymentsPost201ResponseRiskInformationIpAddress(unittest.TestCase):
    """ PtsV2PaymentsPost201ResponseRiskInformationIpAddress unit test stubs """

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testPtsV2PaymentsPost201ResponseRiskInformationIpAddress(self):
        """
        Test PtsV2PaymentsPost201ResponseRiskInformationIpAddress
        """
        # FIXME: construct object with mandatory attributes with example values
        #model = CyberSource.models.pts_v2_payments_post201_response_risk_information_ip_address.PtsV2PaymentsPost201ResponseRiskInformationIpAddress()
        pass


if __name__ == '__main__':
    unittest.main()



import sys


def log_exception(logger, message, mconfig):
    if mconfig.enable_log is True:
        print(message)
        print("Error: Check Log file for more details.")
        logger.exception(message)
    sys.exit(1)



def validate_merchant_details_log(logger, message, mconfig):

    if mconfig.enable_log is True:
        print(message)
        print("Error: Check Log file for more details.")
        logger.error(message)
    sys.exit(1)




def validate_default_values(logger, message, mconfig):
    if mconfig.enable_log is True:
        print(message)
        logger.warning(message)




# coding: utf-8

"""
    CyberSource Merged Spec

    All CyberSource API specs merged together. These are available at https://developer.cybersource.com/api/reference/api-reference.html

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import os
import sys
import unittest

import CyberSource
from CyberSource.rest import ApiException
from CyberSource.models.tss_v2_transactions_post201_response__embedded_point_of_sale_information_partner import TssV2TransactionsPost201ResponseEmbeddedPointOfSaleInformationPartner


class TestTssV2TransactionsPost201ResponseEmbeddedPointOfSaleInformationPartner(unittest.TestCase):
    """ TssV2TransactionsPost201ResponseEmbeddedPointOfSaleInformationPartner unit test stubs """

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testTssV2TransactionsPost201ResponseEmbeddedPointOfSaleInformationPartner(self):
        """
        Test TssV2TransactionsPost201ResponseEmbeddedPointOfSaleInformationPartner
        """
        # FIXME: construct object with mandatory attributes with example values
        #model = CyberSource.models.tss_v2_transactions_post201_response__embedded_point_of_sale_information_partner.TssV2TransactionsPost201ResponseEmbeddedPointOfSaleInformationPartner()
        pass


if __name__ == '__main__':
    unittest.main()



import os
from authenticationsdk.util.GlobalLabelParameters import *
from OpenSSL import crypto
import ssl
import base64


class FileCache:

    def __init__(self):
        self.filecache = {}

    def grab_file(self, mconfig, filepath, filename):

        file_mod_time = os.stat(os.path.join(filepath, filename)+GlobalLabelParameters.P12_PREFIX).st_mtime

        if filename not in self.filecache:

            p12 = crypto.load_pkcs12(open(
                os.path.join(filepath, filename)+GlobalLabelParameters.P12_PREFIX,
                'rb').read(), mconfig.key_password)
            cert_str = crypto.dump_certificate(crypto.FILETYPE_PEM, p12.get_certificate())
            der_cert_string = base64.b64encode(ssl.PEM_cert_to_DER_cert(cert_str.decode("utf-8")))
            private_key = crypto.dump_privatekey(crypto.FILETYPE_PEM, p12.get_privatekey()).decode("utf-8")

            self.filecache.setdefault(str(filename), []).append(der_cert_string)
            self.filecache.setdefault(str(filename), []).append(private_key)
            self.filecache.setdefault(str(filename), []).append(file_mod_time)

        if file_mod_time != self.filecache[filename][2]:
            p12 = crypto.load_pkcs12(open(
                os.path.join(filepath, filename) + GlobalLabelParameters.P12_PREFIX,
                'rb').read(), mconfig.key_password)
            cert_str = crypto.dump_certificate(crypto.FILETYPE_PEM, p12.get_certificate())
            der_cert_string = base64.b64encode(ssl.PEM_cert_to_DER_cert(cert_str.decode("utf-8")))
            private_key = crypto.dump_privatekey(crypto.FILETYPE_PEM, p12.get_privatekey()).decode("utf-8")

            self.filecache.setdefault(str(filename), []).append(der_cert_string)
            self.filecache.setdefault(str(filename), []).append(private_key)
            self.filecache.setdefault(str(filename), []).append(file_mod_time)

        return self.filecache[filename]



# coding: utf-8

"""
    CyberSource Merged Spec

    All CyberSource API specs merged together. These are available at https://developer.cybersource.com/api/reference/api-reference.html

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import os
import sys
import unittest

import CyberSource
from CyberSource.rest import ApiException
from CyberSource.models.reporting_v3_purchase_refund_details_get200_response_others import ReportingV3PurchaseRefundDetailsGet200ResponseOthers


class TestReportingV3PurchaseRefundDetailsGet200ResponseOthers(unittest.TestCase):
    """ ReportingV3PurchaseRefundDetailsGet200ResponseOthers unit test stubs """

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testReportingV3PurchaseRefundDetailsGet200ResponseOthers(self):
        """
        Test ReportingV3PurchaseRefundDetailsGet200ResponseOthers
        """
        # FIXME: construct object with mandatory attributes with example values
        #model = CyberSource.models.reporting_v3_purchase_refund_details_get200_response_others.ReportingV3PurchaseRefundDetailsGet200ResponseOthers()
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    CyberSource Merged Spec

    All CyberSource API specs merged together. These are available at https://developer.cybersource.com/api/reference/api-reference.html

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class ShippingAddressListForCustomerLinks(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        '_self': 'ShippingAddressListForCustomerLinksSelf',
        'first': 'ShippingAddressListForCustomerLinksFirst',
        'prev': 'ShippingAddressListForCustomerLinksPrev',
        'next': 'ShippingAddressListForCustomerLinksNext',
        'last': 'ShippingAddressListForCustomerLinksLast'
    }

    attribute_map = {
        '_self': 'self',
        'first': 'first',
        'prev': 'prev',
        'next': 'next',
        'last': 'last'
    }

    def __init__(self, _self=None, first=None, prev=None, next=None, last=None):
        """
        ShippingAddressListForCustomerLinks - a model defined in Swagger
        """

        self.__self = None
        self._first = None
        self._prev = None
        self._next = None
        self._last = None

        if _self is not None:
          self._self = _self
        if first is not None:
          self.first = first
        if prev is not None:
          self.prev = prev
        if next is not None:
          self.next = next
        if last is not None:
          self.last = last

    @property
    def _self(self):
        """
        Gets the _self of this ShippingAddressListForCustomerLinks.

        :return: The _self of this ShippingAddressListForCustomerLinks.
        :rtype: ShippingAddressListForCustomerLinksSelf
        """
        return self.__self

    @_self.setter
    def _self(self, _self):
        """
        Sets the _self of this ShippingAddressListForCustomerLinks.

        :param _self: The _self of this ShippingAddressListForCustomerLinks.
        :type: ShippingAddressListForCustomerLinksSelf
        """

        self.__self = _self

    @property
    def first(self):
        """
        Gets the first of this ShippingAddressListForCustomerLinks.

        :return: The first of this ShippingAddressListForCustomerLinks.
        :rtype: ShippingAddressListForCustomerLinksFirst
        """
        return self._first

    @first.setter
    def first(self, first):
        """
        Sets the first of this ShippingAddressListForCustomerLinks.

        :param first: The first of this ShippingAddressListForCustomerLinks.
        :type: ShippingAddressListForCustomerLinksFirst
        """

        self._first = first

    @property
    def prev(self):
        """
        Gets the prev of this ShippingAddressListForCustomerLinks.

        :return: The prev of this ShippingAddressListForCustomerLinks.
        :rtype: ShippingAddressListForCustomerLinksPrev
        """
        return self._prev

    @prev.setter
    def prev(self, prev):
        """
        Sets the prev of this ShippingAddressListForCustomerLinks.

        :param prev: The prev of this ShippingAddressListForCustomerLinks.
        :type: ShippingAddressListForCustomerLinksPrev
        """

        self._prev = prev

    @property
    def next(self):
        """
        Gets the next of this ShippingAddressListForCustomerLinks.

        :return: The next of this ShippingAddressListForCustomerLinks.
        :rtype: ShippingAddressListForCustomerLinksNext
        """
        return self._next

    @next.setter
    def next(self, next):
        """
        Sets the next of this ShippingAddressListForCustomerLinks.

        :param next: The next of this ShippingAddressListForCustomerLinks.
        :type: ShippingAddressListForCustomerLinksNext
        """

        self._next = next

    @property
    def last(self):
        """
        Gets the last of this ShippingAddressListForCustomerLinks.

        :return: The last of this ShippingAddressListForCustomerLinks.
        :rtype: ShippingAddressListForCustomerLinksLast
        """
        return self._last

    @last.setter
    def last(self, last):
        """
        Sets the last of this ShippingAddressListForCustomerLinks.

        :param last: The last of this ShippingAddressListForCustomerLinks.
        :type: ShippingAddressListForCustomerLinksLast
        """

        self._last = last

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, ShippingAddressListForCustomerLinks):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

import sys
from setuptools import setup, find_packages

NAME = "cybersource-rest-client-python"
VERSION = "0.0.22"
# To install the library, run the following
#
# python setup.py install
#
# prerequisite: setuptools
# http://pypi.python.org/pypi/setuptools

setup(
    name=NAME,
    version=VERSION,
    description="SDK for the CyberSource REST API",
    author_email="developer@cybersource.com",
    url="https://github.com/CyberSource/cybersource-rest-client-python",
    keywords=["Payments API", "CyberSource"],
    install_requires=[
        "certifi",
        "pycryptodome",
        "PyJWT",
        "pyOpenSSL==18.0.0",
        "DateTime",
        "setuptools",
        "six",
        "urllib3",
        "crypto",
        "cryptography==2.6",
    ],
    packages=find_packages(),
    include_package_data=True,
    long_description="CyberSource REST API",
    classifiers=[
        'Intended Audience :: Developers',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Topic :: Software Development :: Libraries :: Python Modules',
    ]
)



# coding: utf-8

"""
    CyberSource Merged Spec

    All CyberSource API specs merged together. These are available at https://developer.cybersource.com/api/reference/api-reference.html

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class PtsV2PaymentsPost201ResponsePaymentInformationInstrumentIdentifier(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'state': 'str'
    }

    attribute_map = {
        'id': 'id',
        'state': 'state'
    }

    def __init__(self, id=None, state=None):
        """
        PtsV2PaymentsPost201ResponsePaymentInformationInstrumentIdentifier - a model defined in Swagger
        """

        self._id = None
        self._state = None

        if id is not None:
          self.id = id
        if state is not None:
          self.state = state

    @property
    def id(self):
        """
        Gets the id of this PtsV2PaymentsPost201ResponsePaymentInformationInstrumentIdentifier.
        Unique identifier for the Instrument Identifier token used in the transaction. When you include this value in your request, many of the fields that can be supplied for an authorization or credit become optional. 

        :return: The id of this PtsV2PaymentsPost201ResponsePaymentInformationInstrumentIdentifier.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this PtsV2PaymentsPost201ResponsePaymentInformationInstrumentIdentifier.
        Unique identifier for the Instrument Identifier token used in the transaction. When you include this value in your request, many of the fields that can be supplied for an authorization or credit become optional. 

        :param id: The id of this PtsV2PaymentsPost201ResponsePaymentInformationInstrumentIdentifier.
        :type: str
        """
        if id is not None and len(id) > 32:
            raise ValueError("Invalid value for `id`, length must be less than or equal to `32`")
        if id is not None and len(id) < 12:
            raise ValueError("Invalid value for `id`, length must be greater than or equal to `12`")

        self._id = id

    @property
    def state(self):
        """
        Gets the state of this PtsV2PaymentsPost201ResponsePaymentInformationInstrumentIdentifier.
        Issuers state for the card number. Valid values: - ACTIVE - CLOSED : The account has been closed. 

        :return: The state of this PtsV2PaymentsPost201ResponsePaymentInformationInstrumentIdentifier.
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """
        Sets the state of this PtsV2PaymentsPost201ResponsePaymentInformationInstrumentIdentifier.
        Issuers state for the card number. Valid values: - ACTIVE - CLOSED : The account has been closed. 

        :param state: The state of this PtsV2PaymentsPost201ResponsePaymentInformationInstrumentIdentifier.
        :type: str
        """

        self._state = state

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, PtsV2PaymentsPost201ResponsePaymentInformationInstrumentIdentifier):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    CyberSource Merged Spec

    All CyberSource API specs merged together. These are available at https://developer.cybersource.com/api/reference/api-reference.html

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class Ptsv2paymentsOrderInformationBillToCompany(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'address1': 'str',
        'address2': 'str',
        'locality': 'str',
        'administrative_area': 'str',
        'postal_code': 'str',
        'country': 'str'
    }

    attribute_map = {
        'name': 'name',
        'address1': 'address1',
        'address2': 'address2',
        'locality': 'locality',
        'administrative_area': 'administrativeArea',
        'postal_code': 'postalCode',
        'country': 'country'
    }

    def __init__(self, name=None, address1=None, address2=None, locality=None, administrative_area=None, postal_code=None, country=None):
        """
        Ptsv2paymentsOrderInformationBillToCompany - a model defined in Swagger
        """

        self._name = None
        self._address1 = None
        self._address2 = None
        self._locality = None
        self._administrative_area = None
        self._postal_code = None
        self._country = None

        if name is not None:
          self.name = name
        if address1 is not None:
          self.address1 = address1
        if address2 is not None:
          self.address2 = address2
        if locality is not None:
          self.locality = locality
        if administrative_area is not None:
          self.administrative_area = administrative_area
        if postal_code is not None:
          self.postal_code = postal_code
        if country is not None:
          self.country = country

    @property
    def name(self):
        """
        Gets the name of this Ptsv2paymentsOrderInformationBillToCompany.
        Name of the customer’s company.  **CyberSource through VisaNet** Credit card networks cannot process transactions that contain non-ASCII characters. CyberSource through VisaNet accepts and stores non-ASCII characters correctly and displays them correctly in reports. However, the limitations of the credit card networks prevent CyberSource through VisaNet from transmitting non-ASCII characters to the credit card networks. Therefore, CyberSource through VisaNet replaces non-ASCII characters with meaningless ASCII characters for transmission to the credit card networks.  For processor-specific information, see the `company_name` field in [Credit Card Services Using the SCMP API.](http://apps.cybersource.com/library/documentation/dev_guides/CC_Svcs_SCMP_API/html) 

        :return: The name of this Ptsv2paymentsOrderInformationBillToCompany.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this Ptsv2paymentsOrderInformationBillToCompany.
        Name of the customer’s company.  **CyberSource through VisaNet** Credit card networks cannot process transactions that contain non-ASCII characters. CyberSource through VisaNet accepts and stores non-ASCII characters correctly and displays them correctly in reports. However, the limitations of the credit card networks prevent CyberSource through VisaNet from transmitting non-ASCII characters to the credit card networks. Therefore, CyberSource through VisaNet replaces non-ASCII characters with meaningless ASCII characters for transmission to the credit card networks.  For processor-specific information, see the `company_name` field in [Credit Card Services Using the SCMP API.](http://apps.cybersource.com/library/documentation/dev_guides/CC_Svcs_SCMP_API/html) 

        :param name: The name of this Ptsv2paymentsOrderInformationBillToCompany.
        :type: str
        """
        if name is not None and len(name) > 60:
            raise ValueError("Invalid value for `name`, length must be less than or equal to `60`")

        self._name = name

    @property
    def address1(self):
        """
        Gets the address1 of this Ptsv2paymentsOrderInformationBillToCompany.
        First line in the street address of the company purchasing the product.

        :return: The address1 of this Ptsv2paymentsOrderInformationBillToCompany.
        :rtype: str
        """
        return self._address1

    @address1.setter
    def address1(self, address1):
        """
        Sets the address1 of this Ptsv2paymentsOrderInformationBillToCompany.
        First line in the street address of the company purchasing the product.

        :param address1: The address1 of this Ptsv2paymentsOrderInformationBillToCompany.
        :type: str
        """
        if address1 is not None and len(address1) > 40:
            raise ValueError("Invalid value for `address1`, length must be less than or equal to `40`")

        self._address1 = address1

    @property
    def address2(self):
        """
        Gets the address2 of this Ptsv2paymentsOrderInformationBillToCompany.
        Additional address information for the company purchasing the product.

        :return: The address2 of this Ptsv2paymentsOrderInformationBillToCompany.
        :rtype: str
        """
        return self._address2

    @address2.setter
    def address2(self, address2):
        """
        Sets the address2 of this Ptsv2paymentsOrderInformationBillToCompany.
        Additional address information for the company purchasing the product.

        :param address2: The address2 of this Ptsv2paymentsOrderInformationBillToCompany.
        :type: str
        """
        if address2 is not None and len(address2) > 40:
            raise ValueError("Invalid value for `address2`, length must be less than or equal to `40`")

        self._address2 = address2

    @property
    def locality(self):
        """
        Gets the locality of this Ptsv2paymentsOrderInformationBillToCompany.
        City in the address of the company purchasing the product.

        :return: The locality of this Ptsv2paymentsOrderInformationBillToCompany.
        :rtype: str
        """
        return self._locality

    @locality.setter
    def locality(self, locality):
        """
        Sets the locality of this Ptsv2paymentsOrderInformationBillToCompany.
        City in the address of the company purchasing the product.

        :param locality: The locality of this Ptsv2paymentsOrderInformationBillToCompany.
        :type: str
        """
        if locality is not None and len(locality) > 30:
            raise ValueError("Invalid value for `locality`, length must be less than or equal to `30`")

        self._locality = locality

    @property
    def administrative_area(self):
        """
        Gets the administrative_area of this Ptsv2paymentsOrderInformationBillToCompany.
        State or province in the address of the company purchasing the product. Use the State, Province, and Territory Codes for the United States and Canada. 

        :return: The administrative_area of this Ptsv2paymentsOrderInformationBillToCompany.
        :rtype: str
        """
        return self._administrative_area

    @administrative_area.setter
    def administrative_area(self, administrative_area):
        """
        Sets the administrative_area of this Ptsv2paymentsOrderInformationBillToCompany.
        State or province in the address of the company purchasing the product. Use the State, Province, and Territory Codes for the United States and Canada. 

        :param administrative_area: The administrative_area of this Ptsv2paymentsOrderInformationBillToCompany.
        :type: str
        """
        if administrative_area is not None and len(administrative_area) > 2:
            raise ValueError("Invalid value for `administrative_area`, length must be less than or equal to `2`")

        self._administrative_area = administrative_area

    @property
    def postal_code(self):
        """
        Gets the postal_code of this Ptsv2paymentsOrderInformationBillToCompany.
        Postal code in the address of the company purchasing the product. The postal code must consist of 5 to 9 digits.  When the company country is the U.S., the 9-digit postal code must follow this format: **[5 digits][dash][4 digits]** #### Example `12345-6789`  When the company country is Canada, the 6-digit postal code must follow this format: **[alpha][numeric][alpha][space][numeric][alpha][numeric]** #### Example `A1B 2C3` 

        :return: The postal_code of this Ptsv2paymentsOrderInformationBillToCompany.
        :rtype: str
        """
        return self._postal_code

    @postal_code.setter
    def postal_code(self, postal_code):
        """
        Sets the postal_code of this Ptsv2paymentsOrderInformationBillToCompany.
        Postal code in the address of the company purchasing the product. The postal code must consist of 5 to 9 digits.  When the company country is the U.S., the 9-digit postal code must follow this format: **[5 digits][dash][4 digits]** #### Example `12345-6789`  When the company country is Canada, the 6-digit postal code must follow this format: **[alpha][numeric][alpha][space][numeric][alpha][numeric]** #### Example `A1B 2C3` 

        :param postal_code: The postal_code of this Ptsv2paymentsOrderInformationBillToCompany.
        :type: str
        """
        if postal_code is not None and len(postal_code) > 10:
            raise ValueError("Invalid value for `postal_code`, length must be less than or equal to `10`")

        self._postal_code = postal_code

    @property
    def country(self):
        """
        Gets the country of this Ptsv2paymentsOrderInformationBillToCompany.
        Country in the address of the company purchasing the product. Use the [ISO Standard Country Codes](https://developer.cybersource.com/library/documentation/sbc/quickref/countries_alpha_list.pdf). 

        :return: The country of this Ptsv2paymentsOrderInformationBillToCompany.
        :rtype: str
        """
        return self._country

    @country.setter
    def country(self, country):
        """
        Sets the country of this Ptsv2paymentsOrderInformationBillToCompany.
        Country in the address of the company purchasing the product. Use the [ISO Standard Country Codes](https://developer.cybersource.com/library/documentation/sbc/quickref/countries_alpha_list.pdf). 

        :param country: The country of this Ptsv2paymentsOrderInformationBillToCompany.
        :type: str
        """
        if country is not None and len(country) > 2:
            raise ValueError("Invalid value for `country`, length must be less than or equal to `2`")

        self._country = country

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, Ptsv2paymentsOrderInformationBillToCompany):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



import hmac
from authenticationsdk.payloaddigest.PayLoadDigest import *
from authenticationsdk.util.GlobalLabelParameters import *


# This method returns value for parameter Signature which is then passed to Signature header
# paramter 'Signature' is calucated based on below keyvalues and then signed with SECRET KEY
# host: Sandbox(apitest.cybersource.com) or Production(api.cybersource.com) hostname
# date: "HTTP-date" format as defined by RFC7231
# (request-target): Should be in format of httpMethod: path Example: "post /pts/v2/payments"
# Digest: Only needed for POST calls. digestString = BASE64( HMAC-SHA256 ( Payload ));

# v-c-merchant-id: set value to Cybersource Merchant ID This ID can be found on EBC portal


class GetSignatureParameter:
    def __init__(self):

        self.merchant_config_sigparam = None
        self.date = None

    def get_signature_parameter(self, mconfig, merchant_secret_key, merchant_id, httpmethod, date):

        self.merchant_config_sigparam = mconfig
        self.date = date

        return self.get_signature_param(merchant_secret_key, merchant_id, httpmethod)

    # This method adds the Host-Date-(request-target)-v-c-merchant_id for get method
    # This method adds the Host-Date-(request-target)-digest-v-c-merchant_id for post method
    def get_signature_param(self, merchant_secret_key, merchant_id, httpmethod):

        signature_list = ([])
        # This method adds the host header
		

        signature_list.append(GlobalLabelParameters.HOST.lower())
        signature_list.append(": ")
        signature_list.append(self.merchant_config_sigparam.request_host)
        signature_list.append("\n")

        # This method adds the date header
        signature_list.append(GlobalLabelParameters.DATE.lower())
        signature_list.append(": ")
        signature_list.append(self.date)

        signature_list.append("\n")

        # This method adds the request-target header
        signature_list.append(GlobalLabelParameters.REQUEST_TARGET)
        signature_list.append(": ")
        # This forms the get_request_target
        if httpmethod.upper() == GlobalLabelParameters.GET:
            get_request_target = GlobalLabelParameters.GET_LOWER_CASE + self.merchant_config_sigparam.request_target
            signature_list.append(get_request_target)
        # This forms the post_request_target
        elif httpmethod.upper() == GlobalLabelParameters.POST:
            post_request_target = GlobalLabelParameters.POST_LOWER_CASE + self.merchant_config_sigparam.request_target
            signature_list.append(post_request_target)
        elif httpmethod.upper() == GlobalLabelParameters.PUT:
            put_request_target = GlobalLabelParameters.PUT_LOWER_CASE + self.merchant_config_sigparam.request_target
            signature_list.append(put_request_target)
        elif httpmethod.upper() == GlobalLabelParameters.PATCH:
            patch_request_target = GlobalLabelParameters.PATCH_LOWER_CASE + self.merchant_config_sigparam.request_target
            signature_list.append(patch_request_target)
        elif httpmethod.upper() == GlobalLabelParameters.DELETE:
            delete_request_target = GlobalLabelParameters.DELETE_LOWER_CASE + self.merchant_config_sigparam.request_target
            signature_list.append(delete_request_target)

        signature_list.append("\n")

        # This method adds the digest header only for post
        if httpmethod.upper() == GlobalLabelParameters.POST or httpmethod.upper() == GlobalLabelParameters.PUT or httpmethod.upper() == GlobalLabelParameters.PATCH :
            digest_get_obj = DigestAndPayload()
            digest = digest_get_obj.string_digest_generation(
                self.merchant_config_sigparam.request_json_path_data)
            signature_list.append(GlobalLabelParameters.DIGEST.lower())
            signature_list.append(": ")
            signature_list.append(GlobalLabelParameters.DIGEST_PREFIX + digest.decode("utf-8"))
            signature_list.append("\n")


        # This method adds the v-c-merchant-id header
        signature_list.append(GlobalLabelParameters.MERCHANT_ID)
        signature_list.append(": ")
        signature_list.append(str(merchant_id))
        sig_value = "".join(signature_list)


        sig_value_string = str(sig_value)
        sig_value_utf = bytes(sig_value_string,encoding='utf-8')

        # Signature string generated from above parameters is signed with secret key hashed with SHA-256
        # Secret key is base 64 decoded before signing

        secret = base64.b64decode(merchant_secret_key)

        hash_value = hmac.new(secret, sig_value_utf, hashlib.sha256)

        return base64.b64encode(hash_value.digest()).decode("utf-8")



# coding: utf-8

"""
    CyberSource Merged Spec

    All CyberSource API specs merged together. These are available at https://developer.cybersource.com/api/reference/api-reference.html

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class Riskv1exportcomplianceinquiriesExportComplianceInformationWeights(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'address': 'str',
        'company': 'str',
        'name': 'str'
    }

    attribute_map = {
        'address': 'address',
        'company': 'company',
        'name': 'name'
    }

    def __init__(self, address=None, company=None, name=None):
        """
        Riskv1exportcomplianceinquiriesExportComplianceInformationWeights - a model defined in Swagger
        """

        self._address = None
        self._company = None
        self._name = None

        if address is not None:
          self.address = address
        if company is not None:
          self.company = company
        if name is not None:
          self.name = name

    @property
    def address(self):
        """
        Gets the address of this Riskv1exportcomplianceinquiriesExportComplianceInformationWeights.
        Degree of correlation between a customer’s address and an entry in the DPL before a match occurs. This field can contain one of the following values: - exact: The address must be identical to the entry in the DPL. - high: (default) The address cannot differ significantly from the entry in the DPL. - medium: The address can differ slightly more from the entry in the DPL. - low: The address can differ significantly from the entry in the DPL. 

        :return: The address of this Riskv1exportcomplianceinquiriesExportComplianceInformationWeights.
        :rtype: str
        """
        return self._address

    @address.setter
    def address(self, address):
        """
        Sets the address of this Riskv1exportcomplianceinquiriesExportComplianceInformationWeights.
        Degree of correlation between a customer’s address and an entry in the DPL before a match occurs. This field can contain one of the following values: - exact: The address must be identical to the entry in the DPL. - high: (default) The address cannot differ significantly from the entry in the DPL. - medium: The address can differ slightly more from the entry in the DPL. - low: The address can differ significantly from the entry in the DPL. 

        :param address: The address of this Riskv1exportcomplianceinquiriesExportComplianceInformationWeights.
        :type: str
        """
        if address is not None and len(address) > 6:
            raise ValueError("Invalid value for `address`, length must be less than or equal to `6`")

        self._address = address

    @property
    def company(self):
        """
        Gets the company of this Riskv1exportcomplianceinquiriesExportComplianceInformationWeights.
        Degree of correlation between a company address and an entry in the DPL before a match occurs. This field can contain one of the following values: - exact: The company name must be identical to the entry in the DPL. - high: (default) The company name cannot differ significantly from the entry in the DPL. - medium: The company name can differ slightly more from the entry in the DPL. - low: The company name can differ significantly from the entry in the DPL. 

        :return: The company of this Riskv1exportcomplianceinquiriesExportComplianceInformationWeights.
        :rtype: str
        """
        return self._company

    @company.setter
    def company(self, company):
        """
        Sets the company of this Riskv1exportcomplianceinquiriesExportComplianceInformationWeights.
        Degree of correlation between a company address and an entry in the DPL before a match occurs. This field can contain one of the following values: - exact: The company name must be identical to the entry in the DPL. - high: (default) The company name cannot differ significantly from the entry in the DPL. - medium: The company name can differ slightly more from the entry in the DPL. - low: The company name can differ significantly from the entry in the DPL. 

        :param company: The company of this Riskv1exportcomplianceinquiriesExportComplianceInformationWeights.
        :type: str
        """
        if company is not None and len(company) > 6:
            raise ValueError("Invalid value for `company`, length must be less than or equal to `6`")

        self._company = company

    @property
    def name(self):
        """
        Gets the name of this Riskv1exportcomplianceinquiriesExportComplianceInformationWeights.
        Degree of correlation between a customer’s name and an entry in the DPL before a match occurs. This field can contain one of the following values: - exact: The name must be identical to the entry in the DPL. - high: (default) The name cannot differ significantly from the entry in the DPL. - medium: The name can differ slightly more from the entry in the DPL. - low: The name can differ significantly the entry in the DPL. 

        :return: The name of this Riskv1exportcomplianceinquiriesExportComplianceInformationWeights.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this Riskv1exportcomplianceinquiriesExportComplianceInformationWeights.
        Degree of correlation between a customer’s name and an entry in the DPL before a match occurs. This field can contain one of the following values: - exact: The name must be identical to the entry in the DPL. - high: (default) The name cannot differ significantly from the entry in the DPL. - medium: The name can differ slightly more from the entry in the DPL. - low: The name can differ significantly the entry in the DPL. 

        :param name: The name of this Riskv1exportcomplianceinquiriesExportComplianceInformationWeights.
        :type: str
        """
        if name is not None and len(name) > 6:
            raise ValueError("Invalid value for `name`, length must be less than or equal to `6`")

        self._name = name

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, Riskv1exportcomplianceinquiriesExportComplianceInformationWeights):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



import jwt
from authenticationsdk.payloaddigest.PayLoadDigest import *
from authenticationsdk.core.TokenGeneration import *
from authenticationsdk.util.Cache import *


class JwtSignatureToken(TokenGeneration):
    def __init__(self):
        self.merchant_config = None
        self.request_body = None
        self.jwt_method = None
        self.date = None

    def jwt_signature_token(self, mconfig, date_time):
        self.merchant_config = mconfig
        self.jwt_method = mconfig.request_type_method
        self.date = date_time

    def get_token(self):
        return self.set_token()

    # This function decides to call the methods responsible for token generation based on the jwt_method
    def set_token(self):
        token = ""

        if self.jwt_method.upper() == GlobalLabelParameters.GET:
            token = self.token_for_get()
        elif self.jwt_method.upper() == GlobalLabelParameters.POST:
            token = self.token_for_post()
        elif self.jwt_method.upper() == GlobalLabelParameters.PUT:
            token = self.token_for_put()
        elif self.jwt_method.upper() == GlobalLabelParameters.DELETE:
            token = self.token_for_delete()
        elif self.jwt_method.upper() == GlobalLabelParameters.PATCH:
            token = self.token_for_patch()

        return token

    # This function has the logic to generate token when the Jwt_method is get
    def token_for_get(self):

        # Setting the jwt body for JWT-get
        jwt_body = {GlobalLabelParameters.JWT_TIME: self.date}
        # reading the p12 file from cache memory
        cache_obj = FileCache()
        cache_memory = cache_obj.grab_file(self.merchant_config, self.merchant_config.key_file_path,
                                           self.merchant_config.key_file_name)
        der_cert_string = cache_memory[0]
        private_key = cache_memory[1]
        # setting the headers  -merchant_id and the public key
        headers_jwt = {
            GlobalLabelParameters.MERCHANT_ID: str(self.merchant_config.key_alias)}
        public_key_list = ([])
        public_key_list.append(der_cert_string.decode("utf-8"))
        public_key_headers = {GlobalLabelParameters.PUBLIC_KEY: public_key_list}
        headers_jwt.update(public_key_headers)


        # generating the token of jwt
        encoded_jwt = jwt.encode(jwt_body, private_key, algorithm='RS256', headers=headers_jwt)

        return encoded_jwt

    def token_for_post(self):

        digest_payload_obj = DigestAndPayload()
        digest = digest_payload_obj.string_digest_generation(
            self.merchant_config.request_json_path_data)
        # Setting the jwt body for JWT-post

        jwt_body = {GlobalLabelParameters.JWT_DIGEST: digest.decode("utf-8"), GlobalLabelParameters.JWT_ALGORITHM: "SHA-256",
                    GlobalLabelParameters.JWT_TIME: self.date}
        # reading the p12 file from cache memory
        cache_obj = FileCache()
        cache_memory = cache_obj.grab_file(self.merchant_config, self.merchant_config.key_file_path,
                                           self.merchant_config.key_file_name)
        der_cert_string = cache_memory[0]
        private_key = cache_memory[1]
        # setting the headers  -merchant_id and the public key
        headers_jwt = {
            GlobalLabelParameters.MERCHANT_ID: str(self.merchant_config.key_alias)}
        public_key_list = ([])
        public_key_list.append(der_cert_string.decode("utf-8"))
        public_key_headers = {GlobalLabelParameters.PUBLIC_KEY: public_key_list}
        headers_jwt.update(public_key_headers)
        # generating the token of jwt
        encoded_jwt = jwt.encode(jwt_body, private_key, algorithm='RS256', headers=headers_jwt)

        return encoded_jwt

    def token_for_put(self):

        digest_payload_obj = DigestAndPayload()
        digest = digest_payload_obj.string_digest_generation(
            self.merchant_config.request_json_path_data)
        # Setting the jwt body for JWT-post
        jwt_body = {GlobalLabelParameters.JWT_DIGEST: digest.decode("utf-8"), GlobalLabelParameters.JWT_ALGORITHM: "SHA-256",
                    GlobalLabelParameters.JWT_TIME: self.date}
        # reading the p12 file from cache memory
        cache_obj = FileCache()
        cache_memory = cache_obj.grab_file(self.merchant_config, self.merchant_config.key_file_path,
                                           self.merchant_config.key_file_name)
        der_cert_string = cache_memory[0]
        private_key = cache_memory[1]
        # setting the headers  -merchant_id and the public key
        headers_jwt = {
            GlobalLabelParameters.MERCHANT_ID: str(self.merchant_config.key_alias)}
        public_key_list = ([])
        public_key_list.append(der_cert_string.decode("utf-8"))
        public_key_headers = {GlobalLabelParameters.PUBLIC_KEY: public_key_list}
        headers_jwt.update(public_key_headers)
        # generating the token of jwt
        encoded_jwt = jwt.encode(jwt_body, private_key, algorithm='RS256', headers=headers_jwt)

        return encoded_jwt

    def token_for_patch(self):

        digest_payload_obj = DigestAndPayload()
        digest = digest_payload_obj.string_digest_generation(
            self.merchant_config.request_json_path_data)
        # Setting the jwt body for JWT-post
        jwt_body = {GlobalLabelParameters.JWT_DIGEST: digest.decode("utf-8"),
                    GlobalLabelParameters.JWT_ALGORITHM: "SHA-256",
                    GlobalLabelParameters.JWT_TIME: self.date}
        # reading the p12 file from cache memory
        cache_obj = FileCache()
        cache_memory = cache_obj.grab_file(self.merchant_config, self.merchant_config.key_file_path,
                                           self.merchant_config.key_file_name)
        der_cert_string = cache_memory[0]
        private_key = cache_memory[1]
        # setting the headers  -merchant_id and the public key
        headers_jwt = {
            GlobalLabelParameters.MERCHANT_ID: str(self.merchant_config.key_alias)}
        public_key_list = ([])
        public_key_list.append(der_cert_string.decode("utf-8"))
        public_key_headers = {GlobalLabelParameters.PUBLIC_KEY: public_key_list}
        headers_jwt.update(public_key_headers)
        # generating the token of jwt
        encoded_jwt = jwt.encode(jwt_body, private_key, algorithm='RS256', headers=headers_jwt)

        return encoded_jwt

    def token_for_delete(self):

        # Setting the jwt body for JWT-get
        jwt_body = {GlobalLabelParameters.JWT_TIME: self.date}
        # reading the p12 file from cache memory
        cache_obj = FileCache()
        cache_memory = cache_obj.grab_file(self.merchant_config, self.merchant_config.key_file_path,
                                           self.merchant_config.key_file_name)
        der_cert_string = cache_memory[0]
        private_key = cache_memory[1]
        # setting the headers  -merchant_id and the public key
        headers_jwt = {
            GlobalLabelParameters.MERCHANT_ID: str(self.merchant_config.key_alias)}
        public_key_list = ([])
        public_key_list.append(der_cert_string.decode("utf-8"))
        public_key_headers = {GlobalLabelParameters.PUBLIC_KEY: public_key_list}
        headers_jwt.update(public_key_headers)
        # generating the token of jwt
        encoded_jwt = jwt.encode(jwt_body, private_key, algorithm='RS256', headers=headers_jwt)

        return encoded_jwt
